/**
 * Script for syncing in WP-admin.
 *
 * @package flo-sync
 */

/* global mf_sync_script_vars */
jQuery( document ).ready(
	function (jQuery) {

		jQuery( '#publish, .save-variation-changes' ).on(
			'click',
			function () {

				if ( 'product' === jQuery( '#post_type' ).val() ) {
					const $title = jQuery( '#title' ).val();

					const title = jQuery.trim( $title );

					if ( '' === title ) {
						alert( mf_sync_script_vars.title_required );
						$title.focus();
						return false;
					}

					const $regular_price = jQuery( '#_regular_price' );

					const regular_price = jQuery.trim( $regular_price.val() );
					const product_type  = jQuery( '#product-type' ).val();

					// Todo: Validate bookable product.
					// Todo: Validate the quick edit.
					if (
						( 'booking' !== product_type && 'variable' !== product_type ) &&
						( '' === regular_price || 0 === regular_price )
					) {
						alert( mf_sync_script_vars.regular_price_required );

						jQuery( '.general_tab > a' ).click();
						$regular_price.focus();
						return false;
					}

					const $sku = jQuery( '#_sku' );

					const sku = jQuery.trim( $sku.val() );

					if ('variable' !== product_type && ('' === sku || 0 === sku)  ) {
						alert( mf_sync_script_vars.sku_required );

						jQuery( '.inventory_tab > a' ).click();
						$sku.focus();
						return false;
					}

					const $mf_account_code = jQuery( '#mf_account_code' );

					const mf_account_code = jQuery.trim( $mf_account_code.val() );

					if ('' === mf_account_code || 0 === mf_account_code) {
						alert( mf_sync_script_vars.account_code_required );

						jQuery( '.mf_tab_tab > a' ).click();
						$mf_account_code.focus();
						return false;
					}

					if ('variable' === product_type) {

						let valid = true;

						const variants_sku = jQuery( "input[name*='variable_sku']" );
						if ( variants_sku.length ) {
							variants_sku.each(
								function () {
									if ( jQuery.trim( jQuery( this ).val() ) === '' ) {
										valid = false;
									}
								}
							);
						}

						const variants_price = jQuery( "input[name*='variable_regular_price']" );
						if ( variants_price.length ) {
							variants_price.each(
								function () {
									if ( jQuery.trim( jQuery( this ).val() ) === '' ) {
										valid = false;
									}
								}
							);
						}

						if ( ! valid) {
							alert( mf_sync_script_vars.variants_sku_price_required );
							jQuery( '.variations_tab > a' ).click();
						}

						return valid;
					}
				}

			}
		);

		new NMF_Ajax_Syncer();
	}
);


class NMF_Ajax_Syncer {
	constructor() {
		this.btn_reactivate_cron    = jQuery( '#mf_btn_reactivate_cron' );
		this.btn_force_sync         = jQuery( "#mf_sync_now" );
		this.btn_resume_sync        = jQuery( "#mf_sync_resume" );
		this.input_auto_resume_sync = jQuery( "#mf_sync_auto_resume" );
		this.textareaStatus         = jQuery( "#mf_sync_status" );
		this.get_all_data_checkbox  = jQuery( '#nmf_get_all_data' );
		this.nonce                  = this.btn_force_sync.data( "nonce" );
		this.current_request        = false;
		this.get_all_data           = true;

		this.start_sync           = this.start_sync.bind( this );
		this.ajax_reactivate_cron = this.ajax_reactivate_cron.bind( this );
		this.attempt_resume_sync  = this.attempt_resume_sync.bind( this );

		// Events.
		this.btn_force_sync.click( this.start_sync );
		this.btn_reactivate_cron.click( this.ajax_reactivate_cron );
		this.btn_resume_sync.click( this.attempt_resume_sync );

		jQuery( '.nmf-ajax-sync-filter' ).click(
			function ( event ) {
				if ( event.ctrlKey ) {
					event.preventDefault();
					if ( ! jQuery( this ).is( ':checked' ) ) {
						jQuery( '.nmf-ajax-sync-filter' ).not( this ).prop( 'checked', false );
					} else {
						jQuery( '.nmf-ajax-sync-filter' ).not( this ).prop( 'checked', true );
					}
				}
			}
		);
	}

	ajax_reactivate_cron(e) {
		e.preventDefault();
		this.textareaStatus.show();
		this.textareaStatus.append( 'Start cron' + "\n" );

		this.ajax_request( 'nmf_reactivate_cron', 'reactivate_cron_finished', false, false );
	}

	reactivate_cron_finished( response ) {
		if (response.success === true) {
			this.textareaStatus.append( 'Cron OK' + "\n" );
		} else {
			this.textareaStatus.append( response.data + "\n" );
		}
	}

	start_sync(e) {
		e.preventDefault();
		this.toggle_button( 0 );
		this.textareaStatus.show();
		this.get_all_data = this.get_all_data_checkbox.is( ':checked' );
		this.get_all_data_checkbox.attr( 'disabled', 'disabled' );

		this.sync_groups();
	}

	sync_groups() {
		this.ajax_request( 'nmf_sync_groups', 'clean_groups' );
	}

	clean_groups() {
		this.ajax_request( 'nmf_clean_groups', 'sync_campaigns' );
	}

	sync_campaigns() {
		this.ajax_request( 'nmf_sync_campaigns', 'clean_campaigns' );
	}

	clean_campaigns() {
		this.ajax_request( 'nmf_clean_campaigns', 'sync_campaigns_article_sets' );
	}

	sync_campaigns_article_sets() {
		this.ajax_request( 'nmf_sync_campaign_article_sets', 'sync_ajax_article_account_codes' );
	}

	sync_ajax_article_account_codes() {
		this.ajax_request( 'nmf_sync_article_account_codes', 'sync_vat_accounts' );
	}

	sync_vat_accounts() {
		this.ajax_request( 'nmf_sync_vat_accounts', 'sync_store_settings' );
	}

	sync_store_settings() {
		this.ajax_request( 'nmf_sync_store_settings', 'sync_income_account_codes' );
	}

	sync_income_account_codes() {
		this.ajax_request( 'nmf_sync_income_account_codes', 'sync_other_account_codes' );
	}

	sync_other_account_codes() {
		this.ajax_request( 'nmf_sync_other_account_codes', 'sync_articles' );
	}

	sync_articles() {
		this.ajax_request( 'nmf_sync_articles', 'sync_article_stock' );
	}

	sync_article_stock() {
		this.ajax_request( 'nmf_sync_article_stock', 'sync_orders' );
	}

	sync_orders() {
		this.ajax_request( 'nmf_sync_orders', 'ajax_requests_completed' );
	}

	ajax_requests_completed() {
		alert( mf_sync_script_vars.sync_completed );
		this.toggle_button( 1 );
		this.get_all_data_checkbox.removeAttr( 'disabled' );
	}

	/**
	 * Ajax request.
	 *
	 * @param action The wp ajax action to perform.
	 * @param callback The js callback function.
	 * @param check_response Whether to check if the response is valid. If true, the callback will only be called if the response is valid.
	 * @param add_started_text Whether to add the started text to the textarea.
	 * @param account Number of the Hub account to sync.
	 * @param page Number of the page to sync.
	 */
	ajax_request(
		action,
		callback,
		check_response = true,
		add_started_text = true,
		account = 0,
		page = 0
	) {
		const _this          = this;
		const $enabled_input = jQuery( '#enabled_' + action );

		this.current_request = {
			'action': action,
			'callback': callback,
			'check_response': check_response,
			'add_started_text': add_started_text,
			'account': account,
			'page': page,
		};

		if ( add_started_text ) {
			this.update_sync_status( 'started', action );
		}

		if ( $enabled_input.length && ! $enabled_input.is( ':checked' ) ) {
			this.update_sync_status( 'skipped', action );
			_this[ callback ]();
			return false;
		}

		jQuery.ajax(
			{
				type : "post",
				dataType : "json",
				timeout: 300000,
				url : mf_sync_script_vars.ajax_url,
				data : {
					action: action,
					security: this.nonce,
					page: page,
					account: account,
					page_size: jQuery( '#mf_sync_per_page' ).val(),
					get_all_data: this.get_all_data,
				},
				success: function ( response ) {
					if ( ! check_response ) {
						_this[ callback ]( response );
					} else {
						if ( 'undefined' !== response.success && response.success ) {
							if ( response.data.skipped ) {
								_this.update_sync_status( 'skipped', action );
								_this[ callback ]( response.data );
							} else if ( response.data.cleaned ) {
								_this.update_sync_status( 'cleaned', action );
								_this[ callback ]( response.data );
							} else {

								if ( response.data.total_pages > ( response.data.page + 1 ) ) { // There are pages left for sync.
									_this.update_sync_status( 'processed', action, response.data );
									_this.ajax_request( action, callback, check_response, false, account, response.data.page + 1 );

								} else if ( response.data.total_accounts > ( account + 1 ) ) { // There are accounts left for sync.
									_this.update_sync_status( 'processed', action, response.data );
									page = 0;
									_this.ajax_request( action, callback, check_response, false, account + 1, page );

								} else { // Sync is completed, got to next.
									_this.update_sync_status( 'processed', action, response.data );
									_this.update_sync_status( 'completed', action, response.data );
									_this[ callback ]( response.data );
								}
							}
						} else {
							_this.handle_sync_error( response );
						}
					}
				},
				error: function ( response ) {
					_this.handle_sync_error( response );
				}
			}
		);
	}

	/**
	 * Reattempt last ajax request.
	 */
	attempt_resume_sync() {
		this.btn_resume_sync.hide();
		this.ajax_request(
			this.current_request.action,
			this.current_request.callback,
			this.current_request.check_response,
			this.current_request.add_started_text,
			this.current_request.account,
			this.current_request.page
		);
	}

	handle_sync_error() {
		if ( this.input_auto_resume_sync.is( ':checked' ) ) {
			this.update_sync_status( 'error_resume' );
			this.attempt_resume_sync();
		} else {
			this.update_sync_status( 'error' );
			this.btn_resume_sync.show();
		}
	}

	update_sync_status( action, action_name = '', data = [] ) {
		let message = '';

		if ( 'started' === action ) {
			message += mf_sync_script_vars.sync_start_processing_sync + ' ' + this.get_readable_action_name( action_name );
		} else if ( 'completed' === action ) {
			message += mf_sync_script_vars.sync_completed_processing + ' ' + this.get_readable_action_name( action_name ) + "\n";
		} else if ( 'processed' === action ) {
			message += mf_sync_script_vars.sync_processed + ' ' + ( data.page + 1 ) + '/' + data.total_pages + ' ' +
				mf_sync_script_vars.sync_processed_for_account + ' ' + ( data.account + 1 ) + '/' + data.total_accounts;
		} else if ( 'skipped' === action ) {
			message += mf_sync_script_vars.sync_skipped_processing + ' ' + this.get_readable_action_name( action_name ) + "\n";
		} else if ( 'cleaned' === action ) {
			message += mf_sync_script_vars.sync_cleaned + ' ' + this.get_readable_action_name( action_name ) + "\n";
		} else if ( 'error' === action ) {
			message += mf_sync_script_vars.sync_error + "\n";
		} else if ( 'error_resume' === action ) {
			message += mf_sync_script_vars.sync_error_resume + "\n";
		}

		this.textareaStatus.append( message + "\n" );

		this.textareaStatus.animate(
			{
				scrollTop:this.textareaStatus[0].scrollHeight - this.textareaStatus.height()
			},
			10
		);
	}

	get_readable_action_name( action_name ) {
		return 'undefined' !== typeof mf_sync_script_vars.ajax_action_names[ action_name ] ? mf_sync_script_vars.ajax_action_names[ action_name ] : action_name;
	}

	toggle_button( state ) {
		if (state) {
			this.btn_force_sync.removeAttr( 'disabled' );
		} else {
			this.btn_force_sync.attr( 'disabled', 'disabled' );
		}
	}
}
