/**
 * Sync settings script.
 *
 * @package flo-sync
 */

jQuery( document ).ready(
	function ( $ ) {
		const $sync_environment_select = $( '#mf_env_select' );
		if ($sync_environment_select.length) { // Is MF Sync settings page?

			let $sync_settings = {
				prod: {},
				test: {},
				selectors: {
					other: {
						only_sync_stock: $( '#sync_only_product_stock_amount' ),
						sync_prod_publish_status: $( '#sync_publish_products_status' ),
						sync_prod_price: $( '#sync_price_select' ),
						sync_prod_title: $( '#sync_product_title_select' ),
						sync_prod_description: $( '#sync_article_description' ),
						sync_prod_images: $( '#sync_pic_select' ),
						sync_prod_tax_class: $( '#sync_product_tax_class' ),
					},
					prod: {},
					test: {}
				}
			};

			toggle_article_sync_fields();
			$sync_settings.selectors.other.only_sync_stock.on( 'change', toggle_article_sync_fields );

			$sync_settings.selectors.prod.accounts = '.hub-account-prod';
			$sync_settings.prod.rows               = $( '.prod-row' );

			$sync_settings.selectors.test.accounts = '.hub-account-test';
			$sync_settings.test.rows               = $( '.test-row' );

			toggle_mf_sync_settings();

			$sync_environment_select.on( 'change', toggle_mf_sync_settings );

			$( '.add-hub-account' ).on( 'click', add_hub_account );
			$( document ).on( 'click', '.disconnect-backoffice-account', disconnect_backoffice_account );

			function toggle_mf_sync_settings() {
				const sync_environment = $sync_environment_select.val();
				let $to_show           = [];
				let $to_hide           = [];

				let selectors_to_show = [];
				let selectors_to_hide = [];

				switch (sync_environment) {
					case 'prod':
						$to_show.push( $sync_settings.prod );
						$to_hide.push( $sync_settings.test );
						selectors_to_show.push( $sync_settings.selectors.prod );
						selectors_to_hide.push( $sync_settings.selectors.test );
						break;
					case 'test':
						$to_show.push( $sync_settings.test );
						$to_hide.push( $sync_settings.prod );
						selectors_to_show.push( $sync_settings.selectors.test );
						selectors_to_hide.push( $sync_settings.selectors.prod );
						break;
				}

				hide_and_show( $to_hide, $to_show, selectors_to_hide, selectors_to_show );
				toggle_hub_account_fields( sync_environment );
			}

			function add_hub_account( event ) {
				event.preventDefault();
				const $link = $( this );
				const $row  = $link.closest( '.add-account-row' );
				const env   = $link.data( 'env' );

				let $clone = $( '#hub-account-template' ).clone();

				$clone.removeAttr( 'id' );

				const current_iterator = mf_api_iterators[ env ]++;

				switch ( env ) {
					case 'prod':
						$clone.addClass( 'hub-account-prod' );
						$clone.find( '.th-title' ).text( mf_sync_settings_script_vars.prod_title );
						break;

					case 'test':
						$clone.addClass( 'hub-account-test' );
						$clone.find( '.th-title' ).text( mf_sync_settings_script_vars.test_title );
						break;
				}

				$clone.find( '.hub-account-url' ).attr( 'name', 'bo_accounts[' + env + '][' + current_iterator + '][api_url]' );
				$clone.find( '.hub-account-user' ).attr( 'name', 'bo_accounts[' + env + '][' + current_iterator + '][api_user]' );
				$clone.find( '.hub-account-pass' ).attr( 'name', 'bo_accounts[' + env + '][' + current_iterator + '][api_pass]' );
				$clone.find( '.hub-account-display_name' ).attr( 'name', 'bo_accounts[' + env + '][' + current_iterator + '][api_display_name]' );
				$clone.find( '.hub-account-enabled' ).attr( 'name', 'bo_accounts[' + env + '][' + current_iterator + '][enabled]' );
				$clone.find( '.hub-account-user-allowed-shipping-methods' ).attr( 'name', 'bo_accounts[' + env + '][' + current_iterator + '][allowed_shipping_methods][]' );

				$clone.find( '.hub-account-url' ).attr( 'id', 'bo_accounts[' + env + '][' + current_iterator + '][api_url]' );
				$clone.find( '.hub-account-user' ).attr( 'id', 'bo_accounts[' + env + '][' + current_iterator + '][api_user]' );
				$clone.find( '.hub-account-pass' ).attr( 'id', 'bo_accounts[' + env + '][' + current_iterator + '][api_pass]' );
				$clone.find( '.hub-account-display_name' ).attr( 'id', 'bo_accounts[' + env + '][' + current_iterator + '][api_display_name]' );
				$clone.find( '.hub-account-enabled' ).attr( 'id', 'bo_accounts[' + env + '][' + current_iterator + '][enabled]' );
				$clone.find( '.hub-account-user-allowed-shipping-methods' ).attr( 'id', 'bo_accounts[' + env + '][' + current_iterator + '][allowed_shipping_methods][]' );

				$clone.find( '.hub-account-url' ).prop( 'required', 'true' );
				$clone.find( '.hub-account-user' ).prop( 'required', 'true' );
				$clone.find( '.hub-account-pass' ).prop( 'required', 'true' );
				$clone.find( '.hub-account-display_name' ).prop( 'required', 'true' );
				$clone.find( '.hub-account-user-allowed-shipping-methods' ).prop( 'required', 'true' );

				$clone.find( '.hub-account-url' ).prev().attr( 'for', 'bo_accounts[' + env + '][' + current_iterator + '][api_url]' );
				$clone.find( '.hub-account-user' ).prev().attr( 'for', 'bo_accounts[' + env + '][' + current_iterator + '][api_user]' );
				$clone.find( '.hub-account-pass' ).prev().attr( 'for', 'bo_accounts[' + env + '][' + current_iterator + '][api_pass]' );
				$clone.find( '.hub-account-display_name' ).prev().attr( 'for', 'bo_accounts[' + env + '][' + current_iterator + '][api_display_name]' );
				$clone.find( '.hub-account-enabled' ).prev().attr( 'for', 'bo_accounts[' + env + '][' + current_iterator + '][enabled]' );
				$clone.find( '.hub-account-user-allowed-shipping-methods' ).prev().attr( 'for', 'bo_accounts[' + env + '][' + current_iterator + '][allowed_shipping_methods][]' );

				$clone.find( '.disconnect-hub-account' ).data( 'env', env );
				$clone.find( '.disconnect-hub-account' ).attr( 'data-env', env );

				$clone.insertBefore( $row );

				toggle_hub_account_fields( env );
			}

			function disconnect_backoffice_account( event ) {
				event.preventDefault();
				const $link = $( this );
				const env   = $link.data( 'env' );
				const $row  = $link.closest( '.hub-account' );
				if ( 'yes' === $link.data( 'existing' ) ) {
					$row.find( 'input, select' ).attr( 'readonly', 'readonly' ).attr( 'name', '' ).attr( 'disabled', 'disabled' );
					$row.find( '.disconnected-text' ).show();
					$link.hide();
				} else {
					$row.remove();
				}

				toggle_hub_account_fields( env );
			}

			function toggle_hub_account_fields( env ) {
				if ( $( '.hub-account-' + env ).length > 1 ) {
					$( '.hub-account-' + env + ' .multi-account-field' ).show();
				} else {
					$( '.hub-account-' + env + ' .multi-account-field' ).hide();
				}
			}

			function toggle_article_sync_fields() {
				if ( 'enabled' === $sync_settings.selectors.other.only_sync_stock.val() ) {
					$sync_settings.selectors.other.sync_prod_publish_status.prop( 'disabled', true );
					$sync_settings.selectors.other.sync_prod_price.prop( 'disabled', true );
					$sync_settings.selectors.other.sync_prod_title.prop( 'disabled', true );
					$sync_settings.selectors.other.sync_prod_description.prop( 'disabled', true );
					$sync_settings.selectors.other.sync_prod_images.prop( 'disabled', true );
					$sync_settings.selectors.other.sync_prod_tax_class.prop( 'disabled', true );
				} else {
					$sync_settings.selectors.other.sync_prod_publish_status.prop( 'disabled', false );
					$sync_settings.selectors.other.sync_prod_price.prop( 'disabled', false );
					$sync_settings.selectors.other.sync_prod_title.prop( 'disabled', false );
					$sync_settings.selectors.other.sync_prod_description.prop( 'disabled', false );
					$sync_settings.selectors.other.sync_prod_images.prop( 'disabled', false );
					$sync_settings.selectors.other.sync_prod_tax_class.prop( 'disabled', false );
				}
			}

			function hide_and_show( $to_hide, $to_show, selectors_to_hide, selectors_to_show ) {

				if ( 'undefined' !== typeof selectors_to_show && selectors_to_show.length ) {
					selectors_to_show.forEach(
						function (selector) {
							if ( 'string' === typeof selector ) {
								$to_show.push( $( selector ) );
							} else {
								$.each(
									selector,
									function (index, inner_selector) {
										$to_show.push( $( inner_selector ) );
									}
								);
							}
						}
					);
				}

				if ( 'undefined' !== typeof selectors_to_hide && selectors_to_hide.length ) {
					selectors_to_hide.forEach(
						function (selector) {
							if ( 'string' === typeof selector ) {
								$to_hide.push( $( selector ) );
							} else {
								$.each(
									selector,
									function (index, inner_selector) {
										$to_hide.push( $( inner_selector ) );
									}
								);
							}
						}
					);
				}

				if ( 'undefined' !== typeof $to_show && $to_show.length ) {
					$.each(
						$to_show,
						function (index, obj) {
							if (obj instanceof jQuery) {
								slide_elem( obj, 'down' );
							} else {
								$.each(
									obj,
									function (index, $elem) {
										slide_elem( $elem, 'down' );
									}
								);
							}
						}
					);
				}

				if ( 'undefined' !== typeof $to_hide && $to_hide.length ) {
					$.each(
						$to_hide,
						function (index, obj) {
							if (obj instanceof jQuery) {
								slide_elem( obj, 'up' );
							} else {
								$.each(
									obj,
									function (index, $elem) {
										slide_elem( $elem, 'up' );
									}
								);
							}
						}
					);
				}
			}

			function slide_elem(elem, direction) {
				if (elem instanceof jQuery) {
					if ('up' === direction) {
						elem.slideUp( 300 );
					} else {
						elem.slideDown( 300 );
					}
				}
			}
		}
	}
);
