<?php
/**
 * Includes public assets.
 *
 * @package flo-sync
 */

namespace NMFS;

/**
 * Class Assets
 */
class Assets {
	/**
	 * Assets constructor.
	 */
	public static function setup(): void {
		add_action( 'wp_enqueue_scripts', array( __CLASS__, 'enqueue_scripts' ) );
		add_action( 'admin_enqueue_scripts', array( __CLASS__, 'enqueue_admin_scripts' ) );
	}

	/**
	 * Enqueue scripts.
	 */
	public static function enqueue_scripts(): void {
		wp_enqueue_script(
			'nmf_sync_frontend_script',
			NMF_PLUGIN_URL . 'assets/js/nmf_sync_frontend.js',
			array( 'jquery' ),
			filemtime( NMF_PLUGIN_DIR . 'assets/js/nmf_sync_frontend.js' ),
			true
		);

		wp_localize_script(
			'nmf_sync_frontend_script',
			'nmf_sync_frontend_script_vars',
			array(
				'ajax_url'                    => admin_url( 'admin-ajax.php' ),
				'shipping_store_update_nonce' => wp_create_nonce( 'nmf-update-shipping-store' ),
			)
		);

		wp_enqueue_style(
			'nmf_sync_frontend_style',
			NMF_PLUGIN_URL . 'assets/css/nmf_sync_frontend.css',
			array(),
			filemtime( NMF_PLUGIN_DIR . 'assets/css/nmf_sync_frontend.css' ),
		);
	}

	/**
	 * Enqueue admin scripts.
	 */
	public static function enqueue_admin_scripts(): void {
		global $pagenow;
		wp_enqueue_script(
			NMF_SYNC,
			NMF_PLUGIN_URL . 'assets/js/mf_sync.js',
			array( 'jquery' ),
			filemtime( NMF_PLUGIN_DIR . 'assets/js/mf_sync.js' ),
			true
		);

		wp_localize_script(
			NMF_SYNC,
			'mf_sync_script_vars',
			array(
				'sku_required'                => __( 'SKU must be set in the Inventory tab.', 'flo-sync' ),
				'account_code_required'       => __( 'Account code must be selected in the Northmill tab.', 'flo-sync' ),
				'title_required'              => __( 'Product name must be set.', 'flo-sync' ),
				'regular_price_required'      => __( 'Regular price must be set in the General tab.', 'flo-sync' ),
				'variants_sku_price_required' => __( 'SKU and Regular price must be set in all the variants.', 'flo-sync' ),
				'sync_start_processing_sync'  => __( 'Start processing:', 'flo-sync' ),
				'sync_completed_processing'   => __( 'Completed:', 'flo-sync' ),
				'sync_skipped_processing'     => __( 'Disabled:', 'flo-sync' ),
				'sync_cleaned'                => __( 'Cleaned:', 'flo-sync' ),
				'sync_processed'              => __( 'Processed page', 'flo-sync' ),
				'sync_processed_for_account'  => __( 'for Hub account', 'flo-sync' ),
				'sync_completed'              => __( 'Sync completed with Northmill.', 'flo-sync' ),
				'sync_error'                  => __( 'Something went wrong. You can attempt to resume the sync using the button above.', 'flo-sync' ),
				'sync_error_resume'           => __( 'Something went wrong. Attempting to resume...', 'flo-sync' ),
				'ajax_action_names'           => array(
					'nmf_sync_article_account_codes' => __( 'Sync article account codes', 'flo-sync' ),
					'nmf_sync_groups'                => __( 'Sync article groups', 'flo-sync' ),
					'nmf_clean_groups'               => __( 'Clean article groups', 'flo-sync' ),
					'nmf_sync_campaigns'             => __( 'Sync campaigns', 'flo-sync' ),
					'nmf_clean_campaigns'            => __( 'Clean campaigns', 'flo-sync' ),
					'nmf_sync_campaign_article_sets' => __( 'Sync article sets', 'flo-sync' ),
					'nmf_sync_vat_accounts'          => __( 'Sync VAT accounts', 'flo-sync' ),
					'nmf_sync_other_account_codes'   => __( 'Sync other account codes', 'flo-sync' ),
					'nmf_sync_store_settings'        => __( 'Sync store settings', 'flo-sync' ),
					'nmf_sync_income_account_codes'  => __( 'Sync income account codes', 'flo-sync' ),
					'nmf_sync_articles'              => __( 'Sync articles', 'flo-sync' ),
					'nmf_sync_article_stock'         => __( 'Sync article stock', 'flo-sync' ),
					'nmf_sync_orders'                => __( 'Sync orders', 'flo-sync' ),
					'nmf_reactivate_cron'            => __( 'Reactivate cron', 'flo-sync' ),
				),
				'ajax_url'                    => admin_url( 'admin-ajax.php' ),
			)
		);

		wp_enqueue_script(
			NMF_SYNC_SETTINGS,
			NMF_PLUGIN_URL . 'assets/js/mf_sync_settings.js',
			array( 'jquery' ),
			filemtime( NMF_PLUGIN_DIR . 'assets/js/mf_sync_settings.js' ),
			true
		);

		wp_localize_script(
			NMF_SYNC_SETTINGS,
			'mf_sync_settings_script_vars',
			array(
				'prod_title' => esc_html__( 'Production stock account', 'flo-sync' ),
				'test_title' => esc_html__( 'Test stock account', 'flo-sync' ),
			)
		);

		wp_enqueue_style(
			NMF_SYNC_SETTINGS_STYLE,
			NMF_PLUGIN_URL . 'assets/css/mf_sync_settings.css',
			array(),
			filemtime( NMF_PLUGIN_DIR . 'assets/css/mf_sync_settings.css' )
		);

		if ( 'admin.php' === $pagenow && 'northmill_flo_sync_status' === $_GET['page'] ) { // phpcs:ignore WordPress.Security.NonceVerification.Recommended
			wp_enqueue_script(
				'nmf_status_script',
				NMF_PLUGIN_URL . 'assets/js/nmf_status.js',
				array( 'jquery' ),
				filemtime( NMF_PLUGIN_DIR . 'assets/js/nmf_status.js' ),
				true
			);

			wp_enqueue_style(
				'nmf_status_style',
				NMF_PLUGIN_URL . 'assets/css/nmf_status.css',
				array(),
				filemtime( NMF_PLUGIN_DIR . 'assets/css/nmf_status.css' )
			);
		}
	}
}
