<?php
/**
 * Plugin setup.
 *
 * @package flo-sync
 */

namespace NMFS;

use NMFS\Sync\Ajax\Ajax;
use NMFS\Product_Fields\Wc_Product_Tab;
use NMFS\Product_Fields\Wc_Product_Tab_Content;
use NMFS\Sync\Admin_Status;
use NMFS\Sync\API\Backoffice_Accounts\Setup as Backoffice_Accounts_Setup;
use NMFS\Sync\Cron\Cron;
use NMFS\Sync\Cron\Cron_Syncers;
use NMFS\Sync\Cron\Locks;
use NMFS\Sync\Items\Articles\Articles;
use NMFS\Sync\Items\Articles\Stock\Checkout;
use NMFS\Sync\Items\Articles\Stock\Shipping;
use NMFS\Sync\Items\Articles\Stock\Stock;
use NMFS\Sync\Items\Articles\Stock\View as Stock_View;
use NMFS\Sync\Items\Campaigns\Campaigns;
use NMFS\Sync\Items\Orders\Orders;
use NMFS\Sync\Items\Orders\Receipts\Receipts;
use NMFS\Sync\Sync_Updated_Status;

defined( 'ABSPATH' ) || exit;

/**
 * Plugin setup class.
 */
class Plugin_Setup {
	/**
	 * Run all setup functions.
	 *
	 * @return void
	 */
	public static function setup(): void {
		i18n::setup();
		Plugin_Activation::setup();

		// Stop if WooCommerce is not enabled.
		if ( ! class_exists( '\WooCommerce' ) ) {
			add_action( 'admin_notices', array( self::class, 'display_woocommerce_not_enabled_notice' ) );
			return;
		}

		Assets::setup();
		Debug::setup();
		new Plugin_Update();
		Plugin_Upgrade::setup();
		Views_Admin::setup();

		// Product_Fields.
		new Wc_Product_Tab();
		new Wc_Product_Tab_Content();

		// Sync.
		Admin_Status::setup();
		Sync_Updated_Status::setup();

		// Sync/Ajax.
		Ajax::setup();

		// Sync/Cron.
		Cron::setup();
		Cron_Syncers::setup();
		Locks::setup();

		// Sync/API/Backoffice_Accounts.
		Backoffice_Accounts_Setup::setup();

		// Sync/Articles.
		Articles::setup();

		// Sync/Articles/Stock.
		Stock::setup();
		Stock_View::setup();
		Checkout::setup();
		Shipping::setup();

		// Sync/Campaigns.
		Campaigns::setup();

		// Sync/Orders.
		Orders::setup();

		// Sync/Receipts.
		Receipts::setup();
	}

	/**
	 * Displays an error notice if the WooCommerce plugin is not enabled.
	 */
	public static function display_woocommerce_not_enabled_notice(): void {
		echo '<div class="error"><p><strong>';

		printf(
			// Translators: %s is a link to the WooCommerce plugin.
			esc_html__(
				'Northmill Sync requires WooCommerce to be installed and active. You can download %s here.',
				'flo-sync'
			),
			'<a href="https://woocommerce.com/" target="_blank">WooCommerce</a>'
		);

		echo '</strong></p></div>';
	}
}
