<?php
/**
 * WooCommerce product tab.
 *
 * @package flo-sync
 */

namespace NMFS\Product_Fields;

defined( 'ABSPATH' ) || exit;

/**
 * Class Wc_Product_Tab
 */
class Wc_Product_Tab {

	/**
	 * Construct class.
	 */
	public function __construct() {
		add_filter( 'woocommerce_product_data_tabs', array( &$this, 'register_tabs' ) );
		add_action( 'admin_head', array( &$this, 'mf_styles' ) );
	}

	/**
	 * Register new tab WooCommerce product data tab.
	 *
	 * @param array $default_tabs Default tabs.
	 *
	 * @return array
	 */
	public function register_tabs( array $default_tabs ): array {
		$custom_product_tab['mf_tab'] = array(
			'label' => __( 'Northmill Sync', 'flo-sync' ),
			'target'  => 'mf_tab',
			'class'   => array(),
		);

		$insert_at_position = 7;
		$tabs               = array_slice( $default_tabs, 0, $insert_at_position, true );
		$tabs               = array_merge( $tabs, $custom_product_tab );
		$tabs               = array_merge( $tabs, array_slice( $default_tabs, $insert_at_position, null, true ) );

		$tabs['inventory']['class'][] = 'show_if_booking';

		return $tabs;
	}

	/**
	 * Add styles to admin head.
	 */
	public function mf_styles(): void {
		?>
		<style>
			#woocommerce-product-data ul.wc-tabs li.mf_tab_options.mf_tab_tab a:before {
				background: url(<?php echo esc_url( NMF_PLUGIN_URL . 'assets/img/nm_logo.png' ); ?>) center center no-repeat;
				content: " " !important;
				background-size: 100%;
				width: 13px;
				height: 13px;
				display: inline-block;
				line-height: 1;
			}
		</style>
		<?php
	}
}
