<?php
/**
 * Northmill Product Tab Content.
 *
 * @package flo-sync
 */

namespace NMFS\Product_Fields;

use NMFS\Sync\Items\Bookkeeping\Article_Account_Codes\Article_Account_Codes;
use WC_Product_Factory;
use WP_Post;

defined( 'ABSPATH' ) || exit;

/**
 * Northmill Product Tab Content.
 */
class Wc_Product_Tab_Content {

	/**
	 * Class constructor.
	 */
	public function __construct() {
		add_action( 'woocommerce_product_data_panels', array( &$this, 'add_custom_product_meta' ) );
		add_action( 'woocommerce_process_product_meta', array( &$this, 'save_custom_product_meta' ) );
		add_action(
			'woocommerce_variation_options_pricing',
			array(
				&$this,
				'add_variation_custom_product_meta',
			),
			10,
			3
		);
	}

	/**
	 * Add meta fields for product edit page.
	 *
	 * @return void
	 */
	public function add_custom_product_meta(): void {
		global $post;
		$product_type = WC_Product_Factory::get_product_type( $post->ID );
		echo '<div id="mf_tab" class="panel woocommerce_options_panel">';
		echo '<div class="options_group">';

		$args = array(
			'id'          => NMF_ARTICLE_ACCOUNT_CODE,
			'label'       => __( 'Northmill Account Code', 'flo-sync' ),
			'description' => __( 'Choose a value.', 'flo-sync' ),
			'value'       => get_post_meta( $post->ID, NMF_ARTICLE_ACCOUNT_CODE, true ),
			'options'     => Article_Account_Codes::get_select_options(),
		);
		woocommerce_wp_select( $args );

		if ( NMF_VARIABLE !== $product_type ) {
			$args = array(
				'label'             => __( 'Northmill Sync Status', 'flo-sync' ),
				'placeholder'       => __( 'Not synced', 'flo-sync' ),
				'id'                => NMF_ARTICLE_SYNC_STATUS,
				'desc_tip'          => true,
				'custom_attributes' => array( 'readonly' => 'readonly' ),
				'description'       => __( 'Sync status with Hub.', 'flo-sync' ),
			);
			woocommerce_wp_text_input( $args );

			$args = array(
				'label'             => __( 'Northmill Sync Data', 'flo-sync' ),
				'placeholder'       => __( 'No sync data available', 'flo-sync' ),
				'id'                => 'mf_last_sync_response',
				'desc_tip'          => true,
				'custom_attributes' => array( 'readonly' => 'readonly' ),
				'description'       => __( 'Last sync data from Hub.', 'flo-sync' ),
			);
			woocommerce_wp_textarea_input( $args );
		}

		do_action( 'nmf_wc_product_tab_content', $post );

		echo '</div>';
		echo '</div>';
	}

	/**
	 * Handle saving custom product meta-information
	 *
	 * @param int $post_id ID of product being saved.
	 *
	 * @return void
	 *
	 * @phpcs:disable WordPress.Security.NonceVerification.Missing
	 */
	public function save_custom_product_meta( int $post_id ): void {
		$mf_account_code = isset( $_POST[ NMF_ARTICLE_ACCOUNT_CODE ] ) ?
			sanitize_text_field( $_POST[ NMF_ARTICLE_ACCOUNT_CODE ] ) :
			'';
		update_post_meta( $post_id, NMF_ARTICLE_ACCOUNT_CODE, $mf_account_code );
	}
	// @phpcs:enable


	/**
	 * Add meta-fields for product variation edit page.
	 *
	 * @param int     $loop           Position in the loop.
	 * @param array   $variation_data Variation data.
	 * @param WP_Post $variation      Post data.
	 *
	 * @return void
	 * @noinspection PhpUnusedParameterInspection WP action/filter function.
	 */
	public function add_variation_custom_product_meta( int $loop, array $variation_data, WP_Post $variation ): void {
		woocommerce_wp_text_input(
			array(
				'id'                => 'mf_sync_status[' . $loop . ']',
				'class'             => 'short',
				'label'             => __( 'Northmill Sync Status', 'flo-sync' ),
				'custom_attributes' => array( 'readonly' => 'readonly' ),
				'value'             => get_post_meta( $variation->ID, NMF_ARTICLE_SYNC_STATUS, true ),
			)
		);

		woocommerce_wp_textarea_input(
			array(
				'id'                => 'mf_last_sync_response[' . $loop . ']',
				'class'             => 'short',
				'label'             => __( 'Northmill Sync Data', 'flo-sync' ),
				'placeholder'       => __( 'No sync data available', 'flo-sync' ),
				'description'       => __( 'Last sync data from Hub.', 'flo-sync' ),
				'desc_tip'          => true,
				'custom_attributes' => array(
					'readonly' => 'readonly',
					'cols'     => 20,
					'rows'     => 2,
				),
				'value'             => get_post_meta( $variation->ID, 'mf_last_sync_response', true ),
			)
		);
	}
}
