<?php
/**
 * Creates Hub account models.
 *
 * @package flo-sync
 */

namespace NMFS\Sync\API\Backoffice_Accounts;

use NMFS\Sync\API\Backoffice_Accounts\Models\Backoffice_Account_Model;
use WP_Post;

/**
 * Class Factory
 */
class Factory {

	/**
	 * Create a Hub account model.
	 *
	 * @param array $data Array of data to create the model from.
	 *
	 * @return Backoffice_Account_Model
	 */
	public static function create( array $data ): Backoffice_Account_Model {
		return new Backoffice_Account_Model(
			array(
				'wp_id'                      => $data['wp_id'] ?? 0,
				'display_name'               => $data['display_name'] ?? $data['org_num'] ?? '',
				'url'                        => $data['url'] ?? '',
				'user'                       => $data['user'] ?? '',
				'pass'                       => $data['pass'] ?? '',
				'env'                        => $data['env'] ?? '',
				'type'                       => $data['type'] ?? 'stock',
				'enabled'                    => $data['enabled'] ?? true,
				'allowed_shipping_methods'   => $data['allowed_shipping_methods'] ?? array(),
				'org_name'                   => $data['org_name'] ?? '',
				'org_num'                    => $data['org_num'] ?? '',
				'last_sync'                  => $data['last_sync'] ?? '',
				'article_account_codes'      => $data['article_account_codes'] ?? array(),
				'income_account_codes'       => $data['income_account_codes'] ?? array(),
				'vat_account_codes'          => $data['vat_account_codes'] ?? array(),
				'shipping_settings'          => $data['shipping_settings'] ?? array(),
				'partial_refund_article_sku' => $data['partial_refund_article_sku'] ?? '',
			)
		);
	}

	/**
	 * Create a Hub model from CPT.
	 *
	 * @param WP_Post $post The post to create the model from.
	 *
	 * @return Backoffice_Account_Model
	 */
	public static function create_from_wp_post( WP_Post $post ): Backoffice_Account_Model {
		$enabled_meta_name                 = Backoffice_Accounts::$cpt_meta_prefix . 'enabled';
		$allowed_shipping_method_meta_name = Backoffice_Accounts::$cpt_meta_prefix . 'allowed_shipping_methods';

		$enabled =
			metadata_exists( 'post', $post->ID, $enabled_meta_name ) ?
				get_post_meta( $post->ID, $enabled_meta_name, true ) :
				true;

		$allowed_shipping_methods =
			metadata_exists( 'post', $post->ID, $allowed_shipping_method_meta_name ) ?
				get_post_meta( $post->ID, $allowed_shipping_method_meta_name, true ) :
				array();

		return new Backoffice_Account_Model(
			array(
				'wp_id'                      => $post->ID,
				'display_name'               => $post->post_title,
				'enabled'                    => $enabled,
				'allowed_shipping_methods'   => $allowed_shipping_methods,
				'url'                        => get_post_meta( $post->ID, Backoffice_Accounts::$cpt_meta_prefix . 'api_url', true ),
				'user'                       => get_post_meta( $post->ID, Backoffice_Accounts::$cpt_meta_prefix . 'api_user', true ),
				'pass'                       => get_post_meta( $post->ID, Backoffice_Accounts::$cpt_meta_prefix . 'api_pass', true ),
				'env'                        => get_post_meta( $post->ID, Backoffice_Accounts::$cpt_meta_prefix . 'api_env', true ),
				'type'                       => get_post_meta( $post->ID, Backoffice_Accounts::$cpt_meta_prefix . 'api_type', true ),
				'org_name'                   => get_post_meta( $post->ID, Backoffice_Accounts::$cpt_meta_prefix . 'org_name', true ),
				'org_num'                    => get_post_meta( $post->ID, Backoffice_Accounts::$cpt_meta_prefix . 'org_num', true ),
				'last_sync'                  => get_post_meta( $post->ID, Backoffice_Accounts::$cpt_meta_prefix . 'last_sync', true ),
				'article_account_codes'      => get_post_meta( $post->ID, Backoffice_Accounts::$cpt_meta_prefix . 'article_account_codes', true ),
				'income_account_codes'       => get_post_meta( $post->ID, Backoffice_Accounts::$cpt_meta_prefix . 'income_account_codes', true ),
				'vat_account_codes'          => get_post_meta( $post->ID, Backoffice_Accounts::$cpt_meta_prefix . 'vat_account_codes', true ),
				'shipping_settings'          => get_post_meta( $post->ID, Backoffice_Accounts::$cpt_meta_prefix . 'shipping_settings', true ),
				'partial_refund_article_sku' => get_post_meta( $post->ID, Backoffice_Accounts::$cpt_meta_prefix . 'partial_refund_article_sku', true ),
			)
		);
	}
}
