<?php
/**
 * Hub Accounts Helpers
 *
 * @package flo-sync
 */

namespace NMFS\Sync\API\Backoffice_Accounts;

use NMFS\Sync\API\Backoffice_Accounts\Models\Backoffice_Account_Model;
use NMFS\Sync\API\API;

defined( 'ABSPATH' ) || exit;

/**
 * Class Helpers
 */
class Helpers {

	/**
	 * Display Hub accounts connection status.
	 *
	 * @return string HTML.
	 */
	public static function get_settings_notices(): string {
		ob_start();
		$failed_accounts = Backoffice_Accounts::get_invalid_accounts();
		if ( ! empty( $failed_accounts ) ) {
			echo '<div class="error notice">';
			echo '<p>' . esc_html__( 'Sorry, we\'re unable to connect with the Hub API for the following accounts, please try again.', 'flo-sync' ) . '</p>';
			echo '<ul>';
			foreach ( $failed_accounts as $account ) {
				echo '<li>' . esc_html( $account->url . ' - ' . $account->user ) . '</li>';
			}
			echo '</ul>';
			echo '</div>';
		}
		Backoffice_Accounts::clear_invalid_accounts();
		return ob_get_clean();
	}

	/**
	 * Test connection to Northmill API, and show results.
	 *
	 * @param Backoffice_Account_Model $account Account to test.
	 *
	 * @return string Connection status HTML.
	 */
	public static function get_connection_status( Backoffice_Account_Model $account ): string {
		if ( ! $account->is_enabled() ) {
			return false;
		}
		$api = new API( $account );

		$store_settings = $api->get_store_settings();

		if ( ! empty( $store_settings->Settings ) ) {
			return '<p style="color: green;">' . esc_html__( 'Connection successful!', 'flo-sync' ) . '</p>';
		}

		return '<p style="color: red;">' . esc_html__( 'Connection failed!', 'flo-sync' ) . '</p>';
	}
}
