<?php
/**
 * Setup Hub Accounts CPT
 *
 * @package flo-sync
 */

namespace NMFS\Sync\API\Backoffice_Accounts;

use NMFS\Debug;

defined( 'ABSPATH' ) || exit;

/**
 * Setup Hub Accounts CPT
 */
class Setup {

	/**
	 * Constructor
	 */
	public static function setup(): void {
		add_action( 'init', array( __CLASS__, 'register_ctp' ) );
	}

	/**
	 * Register CPT
	 */
	public static function register_ctp(): void {
		$labels = array(
			'name'               => _x( 'Hub Accounts', 'Post type general name', 'flo-sync' ),
			'singular_name'      => _x( 'Hub Account', 'Post type singular name', 'flo-sync' ),
			'menu_name'          => _x( 'Hub Accounts', 'Admin Menu text', 'flo-sync' ),
			'name_admin_bar'     => _x( 'Hub Account', 'Add New on Toolbar', 'flo-sync' ),
			'add_new'            => __( 'Add New', 'flo-sync' ),
			'add_new_item'       => __( 'Add New Hub Account', 'flo-sync' ),
			'new_item'           => __( 'New Hub Account', 'flo-sync' ),
			'edit_item'          => __( 'Edit Hub Account', 'flo-sync' ),
			'view_item'          => __( 'View Hub Account', 'flo-sync' ),
			'all_items'          => __( 'All Hub Accounts', 'flo-sync' ),
			'search_items'       => __( 'Search Hub Accounts', 'flo-sync' ),
			'parent_item_colon'  => __( 'Parent Hub Accounts:', 'flo-sync' ),
			'not_found'          => __( 'No accounts found.', 'flo-sync' ),
			'not_found_in_trash' => __( 'No accounts found in Trash.', 'flo-sync' ),
		);

		$args = array(
			'labels'             => $labels,
			'public'             => false,
			'publicly_queryable' => true,
			'show_ui'            => Debug::is_on(),
			'show_in_menu'       => Debug::is_on(),
			'query_var'          => true,
			'rewrite'            => false,
			'has_archive'        => false,
			'hierarchical'       => false,
			'supports'           => array( 'title', 'custom-fields' ),
		);

		register_post_type( 'mf_bo_accounts', $args );
	}
}
