<?php
/**
 * Handles plugin AJAX requests.
 *
 * @package flo-sync
 */

namespace NMFS\Sync\Ajax;

use NMFS\Sync\Ajax\Models\Request_Model;
use NMFS\Sync\Ajax\Models\Sync_Request_Model;
use NMFS\Sync\Cron\Cron;
use NMFS\Settings;
use NMFS\Sync\Items\Articles\Stock\Sync as Stock_Sync;
use NMFS\Sync\Items\Articles\Sync as Article_Sync;
use NMFS\Sync\Items\Bookkeeping\Article_Account_Codes\Sync as Article_Account_Code_Sync;
use NMFS\Sync\Items\Bookkeeping\Income_Account_Codes\Sync as Income_Account_Codes_Sync;
use NMFS\Sync\Items\Bookkeeping\Vat_Account_Codes\Sync as Vat_Account_Sync;
use NMFS\Sync\Items\Bookkeeping\Other_Account_Codes\Sync as Other_Account_Code_Sync;
use NMFS\Sync\Items\Campaigns\Sets\Sync as Article_Set_Sync;
use NMFS\Sync\Items\Campaigns\Sync as Campaign_Sync;
use NMFS\Sync\Items\Groups\Sync as Group_Sync;
use NMFS\Sync\Items\Orders\Sync as Order_Sync;
use NMFS\Sync\Items\Store_Settings\Sync as Store_Settings_Sync;

/**
 * Ajax class.
 */
class Ajax {

	/**
	 * Ajax constructor.
	 */
	public static function setup(): void {

		new Sync_Request_Model(
			array(
				'action'            => 'nmf_sync_article_account_codes',
				'syncer_class_name' => Article_Account_Code_Sync::class,
			)
		);

		new Sync_Request_Model(
			array(
				'action'            => 'nmf_sync_groups',
				'syncer_class_name' => Group_Sync::class,
			)
		);

		new Sync_Request_Model(
			array(
				'action'            => 'nmf_clean_groups',
				'syncer_class_name' => Group_Sync::class,
				'is_cleaner'        => true,
			)
		);

		new Sync_Request_Model(
			array(
				'action'            => 'nmf_sync_campaigns',
				'syncer_class_name' => Campaign_Sync::class,
			)
		);

		new Sync_Request_Model(
			array(
				'action'            => 'nmf_clean_campaigns',
				'syncer_class_name' => Campaign_Sync::class,
				'is_cleaner'        => true,
			)
		);

		new Sync_Request_Model(
			array(
				'action'            => 'nmf_sync_campaign_article_sets',
				'syncer_class_name' => Article_Set_Sync::class,
			)
		);

		new Sync_Request_Model(
			array(
				'action'            => 'nmf_sync_vat_accounts',
				'syncer_class_name' => Vat_Account_Sync::class,
			)
		);

		new Sync_Request_Model(
			array(
				'action'            => 'nmf_sync_other_account_codes',
				'syncer_class_name' => Other_Account_Code_Sync::class,
			)
		);

		new Sync_Request_Model(
			array(
				'action'            => 'nmf_sync_store_settings',
				'syncer_class_name' => Store_Settings_Sync::class,
			)
		);

		new Sync_Request_Model(
			array(
				'action'            => 'nmf_sync_income_account_codes',
				'syncer_class_name' => Income_Account_Codes_Sync::class,
			)
		);

		new Sync_Request_Model(
			array(
				'action'            => 'nmf_sync_articles',
				'syncer_class_name' => Article_Sync::class,
			)
		);

		new Sync_Request_Model(
			array(
				'action'            => 'nmf_sync_article_stock',
				'syncer_class_name' => Stock_Sync::class,
			)
		);

		new Sync_Request_Model(
			array(
				'action'            => 'nmf_sync_orders',
				'syncer_class_name' => Order_Sync::class,
			)
		);

		new Request_Model(
			array(
				'action'           => 'nmf_reactivate_cron',
				'request_function' => array( self::class, 'ajax_reactivate_cron' ),
			)
		);
	}

	/**
	 * Reactive cron from AJAX.
	 *
	 * @return void
	 */
	public static function ajax_reactivate_cron(): void {

		if ( ! Settings::is_setting_enabled( NMF_SYNC_STATUS ) ) {
			wp_send_json_error( __( 'Sync disabled', 'flo-sync' ) );
		}

		if ( is_null( Settings::get( NMF_CRON_SYNC_EVENT_INTERVAL ) ) ) {
			wp_send_json_error( __( 'Invalid sync interval', 'flo-sync' ) );
		}

		$cron_event                = Cron::get_cron_event( 'sync' );
		$cron_updated_successfully = $cron_event->check_status();

		if ( ! $cron_updated_successfully ) {
			wp_send_json_error( __( 'Reset failed. Is cron disabled on your server?', 'flo-sync' ) );
		}

		wp_send_json_success();
	}
}
