<?php
/**
 * Handles cron syncers.
 *
 * @package flo-sync
 */

namespace NMFS\Sync\Cron;

use NMFS\Sync\Cron\Models\Cron_Sync_Model;
use NMFS\Sync\Items\Articles\Stock\Sync as Article_Stock_Sync;
use NMFS\Sync\Items\Articles\Sync as Article_Sync;
use NMFS\Sync\Items\Bookkeeping\Article_Account_Codes\Sync as Article_Account_Code_Sync;
use NMFS\Sync\Items\Bookkeeping\Income_Account_Codes\Sync as Income_Account_Code_Sync;
use NMFS\Sync\Items\Bookkeeping\Other_Account_Codes\Sync as Other_Account_Code_Sync;
use NMFS\Sync\Items\Bookkeeping\Vat_Account_Codes\Sync as Vat_Account_Code_Sync;
use NMFS\Sync\Items\Campaigns\Sets\Sync as Campaign_Set_Sync;
use NMFS\Sync\Items\Campaigns\Sync as Campaign_Sync;
use NMFS\Sync\Items\Groups\Sync as Group_Sync;
use NMFS\Sync\Items\Orders\Sync as Orders_Sync;
use NMFS\Sync\Items\Store_Settings\Sync as Store_Settings_Sync;

/**
 * Class Cron_Syncers
 */
class Cron_Syncers {

	/**
	 * All constructed cron syncers.
	 *
	 * @var Cron_Sync_Model[]
	 */
	private static array $cron_syncers = array();

	/**
	 * Setup cron jobs.
	 */
	public static function setup(): void {
		self::$cron_syncers['group'] = new Cron_Sync_Model(
			array(
				'cron_priority' => 5,
				'syncer'        => new Group_Sync(),
			)
		);

		self::$cron_syncers['order'] = new Cron_Sync_Model(
			array(
				'cron_priority' => 10,
				'syncer'        => new Orders_Sync(),
			)
		);

		self::$cron_syncers['article'] = new Cron_Sync_Model(
			array(
				'cron_priority' => 10,
				'syncer'        => new Article_Sync(),
			)
		);

		self::$cron_syncers['article_stock'] = new Cron_Sync_Model(
			array(
				'cron_priority' => 11,
				'syncer'        => new Article_Stock_Sync(),
			)
		);

		self::$cron_syncers['campaign'] = new Cron_Sync_Model(
			array(
				'cron_priority' => 20,
				'syncer'        => new Campaign_Sync(),
			)
		);

		self::$cron_syncers['campaign_set'] = new Cron_Sync_Model(
			array(
				'cron_priority' => 21,
				'syncer'        => new Campaign_Set_Sync(),
			)
		);

		self::$cron_syncers['article_account_code'] = new Cron_Sync_Model(
			array(
				'cron_priority' => 22,
				'syncer'        => new Article_Account_Code_Sync(),
			)
		);

		self::$cron_syncers['income_account_code'] = new Cron_Sync_Model(
			array(
				'cron_priority' => 22,
				'syncer'        => new Income_Account_Code_Sync(),
			)
		);

		self::$cron_syncers['vat_account_code'] = new Cron_Sync_Model(
			array(
				'cron_priority' => 22,
				'syncer'        => new Vat_Account_Code_Sync(),
			)
		);

		self::$cron_syncers['other_account_code'] = new Cron_Sync_Model(
			array(
				'cron_priority' => 22,
				'syncer'        => new Other_Account_Code_Sync(),
			)
		);

		self::$cron_syncers['store_settings'] = new Cron_Sync_Model(
			array(
				'cron_priority' => 22,
				'syncer'        => new Store_Settings_Sync(),
			)
		);
	}

	/**
	 * Get cron syncer by name.
	 * Flo Light uses this.
	 *
	 * @param string $name Cron syncer name.
	 *
	 * @return Cron_Sync_Model|null
	 */
	public static function get_cron_syncer( string $name ): ?Cron_Sync_Model {
		return self::$cron_syncers[ $name ] ?? null;
	}
}
