<?php
/**
 * Handles locks
 *
 * @package flo-sync
 */

namespace NMFS\Sync\Cron;

use NMFS\Sync\Cron\Models\Lock_Model;

/**
 * Class Locks
 */
class Locks {

	/**
	 * Setup hooks.
	 *
	 * @return void
	 */
	public static function setup(): void {
		add_action( 'wp_ajax_nmf_remove_cron_lock', array( __CLASS__, 'remove_lock' ) );
	}

	/**
	 * Get all locks from DB.
	 *
	 * @return array
	 */
	public static function get_all(): array {
		global $wpdb;

		$results = $wpdb->get_results( "SELECT * FROM $wpdb->options WHERE option_name LIKE 'mf_lock_%'" );

		$locks = array();

		if ( ! $results ) {
			return $locks;
		}

		foreach ( $results as $result ) {
			$info = explode( '_', $result->option_name );
			$type = $info[3];

			// Remove the first 4 elements of the array.
			array_splice( $info, 0, 4 );

			$key = implode( '_', $info );

			if ( ! isset( $locks[ $key ] ) ) {
				$locks[ $key ] = array();
			}

			if ( 'time' === $type ) {
				$locks[ $key ]['time'] = $result->option_value;
			} elseif ( 'value' === $type ) {
				$locks[ $key ]['value'] = $result->option_value;
			}
		}

		return $locks;
	}

	/**
	 * Remove lock from DB.
	 *
	 * @return void
	 */
	public static function remove_lock(): void {
		$slug = htmlspecialchars( $_POST['lock_name'] ?? '' ); // phpcs:ignore WordPress.Security.NonceVerification.Missing

		if ( ! $slug ) {
			wp_send_json_error( 'Invalid lock name', 400 );
		}

		$lock = new Lock_Model( $slug );

		$lock->clear_lock();

		if ( $lock->is_any_lock() ) {
			wp_send_json_error( 'Lock still exists', 500 );
		} else {
			wp_send_json_success();
		}
	}
}
