<?php
/**
 * Factory for article account codes.
 *
 * @package flo-sync
 */

namespace NMFS\Sync\Items\Bookkeeping\Article_Account_Codes;

use NMFS\Sync\Items\Bookkeeping\Article_Account_Codes\Models\Article_Account_Code_Model;

/**
 * Class Factory
 */
class Factory {
	/**
	 * Create article account code from API data.
	 *
	 * @param mixed $api_data Data from API.
	 *
	 * @return Article_Account_Code_Model[]
	 */
	public static function create_array_from_api( mixed $api_data ): array {
		if ( empty( $api_data ) || ! is_array( $api_data ) ) {
			return array();
		}

		$nmf_tax_classes = array();

		foreach ( $api_data as $tax_class ) {
			$nmf_tax_classes[ $tax_class->AccountCode->Id ] = new Article_Account_Code_Model(
				array(
					'id'           => $tax_class->AccountCode->Id,
					'name'         => $tax_class->AccountCode->Name,
					'slug'         => 'mf-' . sanitize_title( str_replace( ' ', '-', strtolower( $tax_class->AccountCode->Name ) ) ),
					'description'  => $tax_class->AccountCode->Description,
					'vat_rate'     => $tax_class->AccountCode->VatRate,
					'account_code' => $tax_class->AccountCode->Account,
					'cost_center'  => $tax_class->AccountCode->CostCenter,
					'project'      => $tax_class->AccountCode->Project,
				)
			);
		}

		return $nmf_tax_classes;
	}
}
