<?php

namespace NMFS\Sync\Items\Campaigns\Models;

defined( 'ABSPATH' ) || exit;

class Product_Model {
	/**
	 * @param string $name
	 * @param string $sku
	 * @param float  $price Price inc VAT
	 * @param int    $vat_rate
	 */
	public function __construct( string $name, string $sku, float $price, int $vat_rate ) {
		$this->set_name( $name );
		$this->set_sku( $sku );
		$this->set_price( $price );
		$this->vat_rate = $vat_rate;
	}

	/** @return string */
	public function get_name(): string {
		return $this->name;
	}

	/** @param string $name */
	public function set_name( string $name ): void {
		$this->name = $name;
	}

	/** @return string */
	public function get_sku(): string {
		return $this->sku;
	}

	/** @param string $sku */
	public function set_sku( string $sku ): void {
		$this->sku = $sku;
	}

	/** @return float */
	public function get_price(): float {
		return $this->price;
	}

	/** @param float $price */
	public function set_price( float $price ): void {
		$this->price = $price;
	}

	/**
	 * Gets discount
	 *
	 * @param bool $remove_vat Set this to true to remove vat of discount. Used if prices are ex tax in Woo.
	 *
	 * @return float
	 */
	public function get_discount( bool $remove_vat = false ): float {
		return $remove_vat
			? $this->discount / ( 1 + ( $this->vat_rate / 100.0 ) )
			: $this->discount;
	}

	/** @param float $discount */
	public function set_discount( float $discount ): void {
		$this->discount = $discount;
	}

	/** @return int */
	public function get_uses(): int {
		return $this->uses;
	}

	/** Adds a use to this product */
	public function add_use(): void {
		++$this->uses;
	}

	/** @var string */
	protected string $name;
	/** @var string */
	protected string $sku;
	/** @var float */
	protected float $price = 0.0;
	/** @var float */
	protected float $discount = 0.0;
	/** @var int */
	protected int $vat_rate;
	/** @var int */
	protected int $uses = 0;
}
