<?php
/**
 * Article model.
 *
 * @package flo-sync
 */

namespace NMFS\Sync\Items\Orders\Receipts\Models;

use JsonSerializable;
use NMFS\Models\Base_Model;

class Article_Model extends Base_Model implements JsonSerializable {
	/** @var int */
	protected int $OrderIndex;

	/** @var string */
	protected string $ArticleNumber;

	/** @var string */
	protected string $Name;

	/** @var int */
	protected int $Quantity;

	/** @var float */
	protected float $UnitPrice;

	/** @var float */
	protected float $UnitPriceWithoutDiscounts;

	/** @var int */
	protected int $VatRate;

	/** @var float */
	protected float $TotalPriceIncVat;

	/** @var float */
	protected float $TotalPriceExVat;

	/** @var float */
	protected float $TotalVat;

	/** @var string */
	protected string $BookkeepingAccount;

	/** @var array */
	protected array $Discounts;

	/** @var array */
	protected array $Attributes;

	/** @var array */
	protected array $taxes_totals;

	/** @var string */
	protected string $type;

	/**
	 * Gets total tax for specific rate.
	 *
	 * @param int $rate_id Rate ID.
	 *
	 * @return float|null Total tax on success, else null.
	 */
	public function get_tax_total( int $rate_id ): ?float {
		return $this->taxes_totals['total'][ $rate_id ] ?? null;
	}

	/**
	 * @return float
	 */
	public function get_total_price_inc_vat(): float {
		return $this->TotalPriceIncVat;
	}

	/**
	 * @return float
	 */
	public function get_total_price_ex_vat(): float {
		return $this->TotalPriceExVat;
	}

	/**
	 * @return string
	 */
	public function get_bookkeeping_account(): string {
		return $this->BookkeepingAccount;
	}

	/**
	 * @return string
	 */
	public function get_type(): string {
		return $this->type;
	}

	/**
	 * @return string
	 */
	public function get_sku(): string {
		return $this->ArticleNumber;
	}

	/**
	 * @return string
	 */
	public function get_name(): string {
		return $this->Name;
	}

	/**
	 * @return int
	 */
	public function get_quantity(): int {
		return $this->Quantity;
	}

	/**
	 * @return float
	 */
	public function get_unit_price(): float {
		return $this->UnitPrice;
	}

	/**
	 * @return float
	 */
	public function get_unit_price_without_discounts(): float {
		return $this->UnitPriceWithoutDiscounts;
	}

	/**
	 * @return int
	 */
	public function get_vat_rate(): int {
		return $this->VatRate;
	}

	/**
	 * @return float Discount as a float. Must be rounded before use.
	 */
	public function get_total_discount(): float {
		return array_reduce(
			$this->Discounts,
			function ( $carry, $discount ) {
				if ( 'amount' == $discount['DiscountType'] ) {
					return $carry + $discount['Amount'];
				}

				return 0.0;
			},
			0.0
		);
	}

	public function jsonSerialize(): array {
		return array(
			'OrderIndex'       => $this->OrderIndex ?? null,
			'ArticleNumber'    => $this->ArticleNumber,
			'Name'             => $this->Name,
			'Quantity'         => $this->Quantity,
			'UnitPrice'        => $this->UnitPrice,
			'VatRate'          => $this->VatRate,
			'TotalPriceIncVat' => $this->TotalPriceIncVat,
			'TotalPriceExVat'  => $this->TotalPriceExVat,
			'TotalVat'         => $this->TotalVat,
			'Discounts'        => $this->Discounts,
			'Attributes'       => $this->Attributes,
		);
	}
}
