<?php

namespace NMFS\Sync\Items\Orders\Receipts\Models;

use JsonSerializable;
use NMFS\Models\Base_Model;

class Receipt_Model extends Base_Model implements JsonSerializable {
	/** @var int */
	protected int $ReceiptNumber = 0;

	/** @var string */
	protected string $Origin = '';

	/** @var string|null */
	protected ?string $Id = null;

	/** @var string */
	protected string $ReceiptType = '';

	/** @var string|null */
	protected ?string $InternalNote = null;

	/** @var string */
	protected string $TransactionDate;

	/** @var string|null */
	protected ?string $CashierName = null; // Den som tar ut kvittot och ger till kunden, finns ingen sådan i Woo

	/** @var float */
	protected float $TotalPriceIncVat = 0;

	/** @var float */
	protected float $TotalPriceExVat = 0;

	/** @var float */
	protected float $TotalVat = 0;

	/** @var bool */
	protected bool $DoStockMgmt = true;

	/** @var Merchant_Model */
	protected Merchant_Model $Merchant;

	/** @var int[] */
	protected ?array $Rounding = null;

	/** @var string[] */
	protected ?array $ControlUnit = null;

	/** @var Customer_Model[] */
	protected array $Customers = array();

	/** @var Article_Model[] */
	protected array $Articles = array();

	/** @var Payment_Model[] */
	protected array $Payments = array();

	/** @var Vat_Model[] */
	protected array $Vat = array();

	/** @var Order_Reference_Model[] */
	protected array $Orders = array();

	/** @var Receipt_Discount_Model[] */
	protected array $Discounts = array();

	/** @var array */
	protected array $Recipients = array();

	/** @var array|null */
	protected ?array $TextRows = null;

	/** @var string[]|null */
	protected ?array $ClientDetails = null;

	/** @var Voucher_Model|null */
	protected ?Voucher_Model $Voucher = null;

	public function get_voucher(): ?Voucher_Model {
		return $this->Voucher;
	}

	public function get_articles(): array {
		return $this->Articles;
	}

	public function jsonSerialize(): array {
		return array(
			'ReceiptNumber'    => $this->ReceiptNumber,
			'Origin'           => $this->Origin,
			'Id'               => $this->Id,
			'ReceiptType'      => $this->ReceiptType,
			'InternalNote'     => $this->InternalNote,
			'TransactionDate'  => $this->TransactionDate,
			'CashierName'      => $this->CashierName,
			'TotalPriceIncVat' => $this->TotalPriceIncVat,
			'TotalPriceExVat'  => $this->TotalPriceExVat,
			'TotalVat'         => $this->TotalVat,
			'DoStockMgmt'      => $this->DoStockMgmt,
			'Merchant'         => $this->Merchant,
			'Rounding'         => $this->Rounding,
			'ControlUnit'      => $this->ControlUnit,
			'Customers'        => $this->Customers,
			'Articles'         => $this->Articles,
			'Payments'         => $this->Payments,
			'Vat'              => $this->Vat,
			'Orders'           => $this->Orders,
			'Discounts'        => $this->Discounts,
			'Recipients'       => $this->Recipients,
			'TextRows'         => $this->TextRows,
			'ClientDetails'    => $this->ClientDetails,
			'Voucher'          => $this->Voucher,
		);
	}
}
