<?php
/**
 * Settings view.
 *
 * @package flo-sync
 */

/**
 * View arguments.
 *
 * @var array $args
 */

use NMFS\Views_Admin;

defined( 'ABSPATH' ) || exit;
?>
<div class="wrap">
	<h1><?php esc_html_e( 'Northmill Sync Settings', 'flo-sync' ); ?></h1>
</div>

<?php echo $args['settings_notices']; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>

<form method="post" action=''>
	<table class="form-table">
		<tr>
			<th colspan="2"><h2 class="title"><?php esc_html_e( 'Connection', 'flo-sync' ); ?></h2></th>
		</tr>
		<?php
		Views_Admin::render_setting_select_field(
			'mf_env_select',
			__( 'Environment', 'flo-sync' ),
			$args['current_env'],
			$args['valid_envs']
		);
		?>
		<tr>
			<th colspan="2"><h4 class="title"><?php esc_html_e( 'API Accounts', 'flo-sync' ); ?></h4></th>
		</tr>
		<?php
		Views_Admin::render_backoffice_account_fields(
			$field_iterators,
			null,
			false,
			true
		);

		Views_Admin::render_backoffice_account_fields(
			$field_iterators,
			$args['test_main_account']
		);
		?>
		<tbody class="add-account-row test-row">
		<tr>
			<th colspan="2"><p>
					<?php esc_html_e( 'Any accounts connected below are listed in checkout to be ordered from, along with the main account. It is used to create orders, sync stock and retrieve bookkeeping information.', 'flo-sync' ); ?>
				</p></th>
		</tr>
		</tbody>
		<?php

		foreach ( $args['stock_accounts'] as $account_id => $account ) {
			if ( $account->is_test() ) {
				Views_Admin::render_backoffice_account_fields(
					$field_iterators,
					$account
				);

				unset( $args['stock_accounts'][ $account_id ] );
			}
		}
		?>
		<tbody class="add-account-row test-row">
			<tr>
				<th colspan="2"><a href="#" class="add-hub-account" data-env="test"><?php esc_html_e( 'Connect stock Hub account', 'flo-sync' ); ?></a></th>
			</tr>
		</tbody>
		<?php
		Views_Admin::render_backoffice_account_fields(
			$field_iterators,
			$args['prod_main_account'],
			'prod'
		);
		?>
		<tbody class="add-account-row prod-row">
			<tr>
				<th colspan="2"><p>
						<?php esc_html_e( 'Any accounts connected below are listed in checkout to be ordered from, along with the main account. It is used to create orders, sync stock and retrieve bookkeeping information.', 'flo-sync' ); ?>
					</p></th>
			</tr>
		</tbody>
		<?php
		foreach ( $args['stock_accounts'] as $account ) {
			Views_Admin::render_backoffice_account_fields(
				$field_iterators,
				$account
			);
		}
		?>
		<tbody class="add-account-row prod-row">
			<tr>
				<th colspan="2"><a href="#" class="add-hub-account" data-env="prod"><?php esc_html_e( 'Connect stock Hub account', 'flo-sync' ); ?></a></th>
			</tr>
		</tbody>


		<tr>
			<th colspan="2" style="border-top: 1px solid #5C5C5C;"><h2 class="title"><?php esc_html_e( 'Sync options', 'flo-sync' ); ?></h2></th>
		</tr>
		<?php

		Views_Admin::render_enabled_disabled_field(
			'mf_sync_status',
			__( 'Automatic sync', 'flo-sync' ),
			$args['mf_auto_sync'],
		);

		Views_Admin::render_enabled_disabled_field(
			'sync_new_orders_to_apps',
			__( 'Synchronize new orders to Hub', 'flo-sync' ),
			$args['orders_to_apps_status'],
			__( 'Select "Enabled" to sync all incoming orders to Hub.', 'flo-sync' )
		);

		Views_Admin::render_enabled_disabled_field(
			'sync_only_product_stock_amount',
			__( 'Only sync product stock amount', 'flo-sync' ),
			$args['sync_only_product_stock_amount'],
			__( 'When "Enabled", only stock amount will be synced for products, no other product data. Also, no new products will be synced.', 'flo-sync' )
		);

		Views_Admin::render_enabled_disabled_field(
			'sync_publish_products_status',
			__( 'Synchronize publish status of products', 'flo-sync' ),
			$args['products_publish_status'],
			__( 'Choose "Enabled" to publish new products when they are synced from Hub and set them to draft when deactivated in Hub.', 'flo-sync' ) . '<br>' .
				__( 'When "Disabled", products will be set as draft and you can publish them manually.', 'flo-sync' )
		);

		Views_Admin::render_enabled_disabled_field(
			'sync_price_select',
			__( 'Synchronize Price', 'flo-sync' ),
			$args['sync_price_status'],
			__( 'Select "Enabled" to sync prices.', 'flo-sync' )
		);

		Views_Admin::render_enabled_disabled_field(
			'sync_article_description',
			__( 'Synchronize Article Description', 'flo-sync' ),
			$args['sync_article_description'],
			__( 'Choose "Enabled" to sync article description from Hub to WooCommerce. Any current content or changes to the content in WooCommerce will be replaced.', 'flo-sync' )
		);

		Views_Admin::render_enabled_disabled_field(
			'sync_pic_select',
			__( 'Synchronize Pictures', 'flo-sync' ),
			$args['sync_pictures_status'],
			__( 'Select "Enabled" to sync pictures.', 'flo-sync' )
		);

		Views_Admin::render_enabled_disabled_field(
			'sync_product_title_select',
			__( 'Synchronize Product Title', 'flo-sync' ),
			$args['sync_product_title_status'],
			__( 'Select "Enabled" to sync product title.', 'flo-sync' )
		);

		Views_Admin::render_enabled_disabled_field(
			'sync_product_display_order_select',
			__( 'Synchronize Product Display Order', 'flo-sync' ),
			$args['sync_product_display_order_status'],
			__( 'Select "Enabled" to sync product display order.', 'flo-sync' )
		);

		Views_Admin::render_enabled_disabled_field(
			'sync_product_tax_class',
			__( 'Synchronize Tax Classes', 'flo-sync' ),
			$args['sync_product_tax_class_status'],
			__( 'Select "Enabled" to sync tax classes.', 'flo-sync' )
		);

		Views_Admin::render_enabled_disabled_field(
			'sync_campaigns',
			__( 'Synchronize Campaigns', 'flo-sync' ),
			$args['sync_campaigns_status'],
			__( 'Choose "Enabled" to sync campaigns from Hub to WooCommerce and use them in this shop. This feature should not be used together with other discounting plugins.', 'flo-sync' )
		);

		Views_Admin::render_enabled_disabled_field(
			'sync_product_categories',
			__( 'Synchronize Article Group', 'flo-sync' ),
			$args['sync_product_categories_status'],
			__( 'Select "Enabled" to sync groups to WooCommerce as product categories. Also changes the category for synced products to the articles\' group.', 'flo-sync' )
		);

		Views_Admin::render_setting_select_field(
			'mf_order_stock_adjustment',
			__( 'Adjust stock when', 'flo-sync' ),
			$args['sync_order_stock_adjustment'],
			$args['available_stock_adjust_options'],
			__( 'This determines when stock is adjusted in Hub and in WooCommerce.', 'flo-sync' )
		);

		Views_Admin::render_setting_select_field(
			'mf_sync_articles_interval',
			__( 'Syncing Interval', 'flo-sync' ),
			$args['sync_interval'],
			$args['available_schedules'],
			__( 'How often the automatic sync of recent changes in Hub should run.', 'flo-sync' )
		);

		?>
		<tr>
			<th colspan="2">
				<h2 class="title"><?php esc_html_e( 'Receipts', 'flo-sync' ); ?></h2>
			</th>
		</tr>

		<?php

		Views_Admin::render_enabled_disabled_field(
			'sync_receipt_active',
			__( 'Create receipts in Hub', 'flo-sync' ),
			$args['create_receipt_in_apps_status'],
			__( 'Select "Enabled" to create receipts for new orders.', 'flo-sync' ),
			$args['receipts_select_extra_html'],
			$args['receipts_disabled']
		);

		?>
		<tr>
			<th colspan="2"><h2 class="title"><?php esc_html_e( 'Miscellaneous', 'flo-sync' ); ?></h2></th>
		</tr>
		<?php
		Views_Admin::render_setting_select_field(
			'mf_log_level',
			__( 'Plugin log level', 'flo-sync' ),
			$args['current_log_level'],
			$args['available_log_levels'],
			__( 'Set the lowest level that should be logged, all levels above are included.', 'flo-sync' ),
			'<p>' . $args['wc_log_a_tag'] . '</p>'
		);
		?>
		<tr>
			<th colspan="2"><h2 class="title"><?php esc_html_e( 'Advanced', 'flo-sync' ); ?></h2></th>
		</tr>
		<?php
		Views_Admin::render_setting_input_field(
			'hub_order_number_prefix',
			__( 'Hub order number prefix', 'flo-sync' ),
			$args['hub_order_number_prefix'],
			__( 'Do NOT edit this if you do not know what you are doing. It will affect your order numbers, and might cause order collisions.', 'flo-sync' )
		);
		?>
	</table>

	<p class="submit"><input type="submit" name="mf_submit_options" class="button button-primary" value="Save Options"></p>
</form>
<script>
	let mf_api_iterators = {
		prod: <?php echo esc_html( $field_iterators['prod'] ); ?>,
		test: <?php echo esc_html( $field_iterators['test'] ); ?>
	};
</script>
