<?php
/**
 * Renders a Hub account settings field.
 *
 * @package flo-sync
 */

/**
 * View arguments.
 *
 * @var array $args
 */

?>
<tbody
	<?php echo $args['tbody_id']; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
		class="hub-account <?php echo esc_attr( $args['tbody_class'] ); ?>"
>
	<tr>
		<th scope="row">
				<span class="th-title">
					<?php echo esc_html( $args['row_title'] ); ?>
				</span>
			<?php echo $args['connection_status']; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
			<?php if ( ! $args['is_main'] ) : ?>
				<p>
					<a
						href="#"
						class="disconnect-backoffice-account"
						data-env="<?php echo esc_attr( $args['api_env'] ); ?>"
						data-existing="<?php echo 'template' !== $args['api_env'] ? 'yes' : 'no'; ?>"
					>
						<?php esc_html_e( 'Disconnect account', 'flo-sync' ); ?>
					</a>
					<span class="disconnected-text" style="display: none; font-style: italic;">
						<?php esc_html_e( 'Account will be disconnected on save', 'flo-sync' ); ?>
					</span>
				</p>
			<?php endif; ?>
			<p>
				<?php echo esc_html( $args['row_desc'] ); ?>
			</p>
		</th>
		<td>
			<label for="<?php echo esc_attr( $args['url_input_id'] ); ?>">
				<?php
				esc_html_e( 'API URL', 'flo-sync' );
				echo ! $args['is_main'] ? '*' : '';
				?>
			</label>
			<input
				type="url"
				id="<?php echo esc_attr( $args['url_input_id'] ); ?>"
				name="<?php echo esc_attr( $args['url_input_id'] ); ?>"
				class="regular-text code hub-account-url"
				value="<?php echo esc_attr( $args['api_url'] ); ?>"
				placeholder="https://api.moreflo.com"
				<?php echo $args['make_input_required'] ? 'required' : ''; ?>
			/>

			<label for="<?php echo esc_attr( $args['user_input_id'] ); ?>">
				<?php
				esc_html_e( 'Username', 'flo-sync' );
				echo ! $args['is_main'] ? '*' : '';
				?>
			</label>
			<input
				type="text"
				id="<?php echo esc_attr( $args['user_input_id'] ); ?>"
				name="<?php echo esc_attr( $args['user_input_id'] ); ?>"
				class="regular-text code hub-account-user"
				value="<?php echo esc_attr( $args['api_user'] ); ?>"
				placeholder="<?php esc_attr_e( 'Username', 'flo-sync' ); ?>"
				<?php echo $args['make_input_required'] ? 'required' : ''; ?>
			/>

			<label for="<?php echo esc_attr( $args['pass_input_id'] ); ?>">
				<?php
				esc_html_e( 'Password', 'flo-sync' );
				echo ! $args['is_main'] ? '*' : '';
				?>
			</label>
			<input
				type="password"
				id="<?php echo esc_attr( $args['pass_input_id'] ); ?>"
				name="<?php echo esc_attr( $args['pass_input_id'] ); ?>"
				class="regular-text code hub-account-pass"
				value="<?php echo esc_attr( $args['api_pass'] ); ?>"
				placeholder="<?php esc_attr_e( 'Password', 'flo-sync' ); ?>"
				<?php echo $args['make_input_required'] ? 'required' : ''; ?>
			/>

			<label
				for="<?php echo esc_attr( $args['display_name_input_id'] ); ?>"
				class="multi-account-field"
			>
				<?php
				esc_html_e( 'Display name', 'flo-sync' );
				echo ! $args['is_main'] ? '*' : '';
				?>
			</label>
			<input
				type="text"
				id="<?php echo esc_attr( $args['display_name_input_id'] ); ?>"
				name="<?php echo esc_attr( $args['display_name_input_id'] ); ?>"
				class="regular-text code hub-account-display_name multi-account-field"
				value="<?php echo esc_attr( $args['display_name'] ); ?>"
				placeholder="<?php esc_attr_e( 'Display name', 'flo-sync' ); ?>"
				<?php echo $args['make_input_required'] ? 'required' : ''; ?>
			/>

			<label
				for="<?php echo esc_attr( $args['shipping_methods_id'] ); ?>"
				class="multi-account-field"
			>
				<?php
				esc_html_e( 'Shipping methods', 'flo-sync' );
				echo ! $args['is_main'] ? '*' : '';
				?>
			</label>
			<?php echo $args['shipping_methods_multi_select']; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
			<p class="description multi-account-field">
				<?php esc_html_e( 'Select all shipping methods allowed to use for this account.', 'flo-sync' ); ?>
			</p>

			<?php if ( ! $args['is_main'] ) : ?>
				<label for="<?php echo esc_attr( $args['enabled_input_id'] ); ?>">
					<?php esc_html_e( 'Enabled', 'flo-sync' ); ?>
				</label>
				<select
					name="<?php echo esc_attr( $args['enabled_input_id'] ); ?>"
					id="<?php echo esc_attr( $args['enabled_input_id'] ); ?>"
					class="hub-account-enabled"
				>
					<option value="enabled" <?php selected( $args['account_enabled'] ); ?>>
						<?php echo esc_html__( 'Enabled', 'flo-sync' ); ?>
					</option>
					<option value="disabled" <?php selected( $args['account_enabled'], false ); ?>>
						<?php echo esc_html__( 'Disabled', 'flo-sync' ); ?>
					</option>
				</select>
				<p class="description">
					<?php esc_html_e( 'If disabled, this account will not be used for any sync.', 'flo-sync' ); ?>
				</p>
			<?php endif; ?>
		</td>
	</tr>
</tbody>
