<?php
/**
 * Displays the status page
 *
 * @package flo-sync
 */

use NMFS\DB_Helpers;
use NMFS\Debug;
use NMFS\Helpers;
use NMFS\Settings;
use NMFS\Sync\API\Backoffice_Accounts\Backoffice_Accounts;
use NMFS\Sync\Cron\Cron;
use NMFS\Sync\Cron\Locks;
use NMFS\Sync\Sync_Updated_Status;

defined( 'ABSPATH' ) || exit;

// phpcs:disable WordPress.PHP.DevelopmentFunctions.error_log_print_r
?>
<div class="wrap">
	<ul id="nm-status-toc">
		<!-- Table of contents for all headings -->
		<li>
			<a href="#main-settings"><?php esc_html_e( 'Main settings', 'flo-sync' ); ?></a>
		</li>
		<li>
			<a href="#latest-syncs"><?php esc_html_e( 'Latest syncs', 'flo-sync' ); ?></a>
		</li>
		<li>
			<a href="#cron-events"><?php esc_html_e( 'Cron events', 'flo-sync' ); ?></a>
		</li>
		<li>
			<a href="#active-crons"><?php esc_html_e( 'Active cron locks', 'flo-sync' ); ?></a>
		</li>
		<li>
			<a href="#hub-accounts"><?php esc_html_e( 'Hub Accounts', 'flo-sync' ); ?></a>
			<ul>
				<li>
					<a href="#mas-sync-status"><?php esc_html_e( 'Multi-account sync status', 'flo-sync' ); ?></a>
				</li>
				<li>
					<a href="#hub-account-list"><?php esc_html_e( 'Accounts', 'flo-sync' ); ?></a>
				</li>
				<li>
					<a href="#invalid-hub-accounts"><?php esc_html_e( 'Invalid Hub Accounts', 'flo-sync' ); ?></a>
				</li>
			</ul>
		</li>
		<li>
			<a href="#income-account-codes"><?php esc_html_e( 'Income Account Codes', 'flo-sync' ); ?></a>
		</li>
		<li>
			<a href="#vat-account-codes"><?php esc_html_e( 'VAT Account Codes', 'flo-sync' ); ?></a>
		</li>
		<li>
			<a href="#article-account-codes"><?php esc_html_e( 'Article Account Codes', 'flo-sync' ); ?></a>
			<ul>
				<li>
					<a href="#table-wc_tax_rate_classes">Table wc_tax_rate_classes</a>
				</li>
				<li>
					<a href="#table-woocommerce_tax_rates">Table woocommerce_tax_rates</a>
				</li>
				<li>
					<a href="#option-mf_tax_rates_cls">Option mf_tax_rates_cls</a>
				</li>
				<li>
					<a href="#option-mf_tax_rates_ids">Option mf_tax_rates_ids</a>
				</li>
				<li>
					<a href="#option-mf_wc_tax_rules">Option mf_wc_tax_rules</a>
				</li>
			</ul>
		</li>
		<li>
			<a href="#woocommerce-settings"><?php esc_html_e( 'WooCommerce settings', 'flo-sync' ); ?></a>
			<ul>
				<li>
					<a href="#price-decimals"><?php esc_html_e( 'Price decimals', 'flo-sync' ); ?></a>
				</li>
			</ul>
		</li>
		<li>
			<a href="#settings-pre-3"><?php esc_html_e( 'Settings Pre 3.0.0', 'flo-sync' ); ?></a>
			<ul>
				<li>
					<a href="#settings-pre-3-main"><?php esc_html_e( 'Main settings', 'flo-sync' ); ?></a>
				</li>
				<li>
					<a href="#settings-pre-3-aac"><?php esc_html_e( 'Article Account Codes', 'flo-sync' ); ?></a>
				</li>
			</ul>
		</li>
	</ul>
	<h2><?php esc_html_e( 'Northmill Sync Plugin Status', 'flo-sync' ); ?></h2>
	<div>
		<h2 id="main-settings"><?php esc_html_e( 'Main settings', 'flo-sync' ); ?></h2>
		<?php
		echo '<pre>';
		print_r( Settings::get_all() );
		echo '</pre>';
		?>
		<h2 id="latest-syncs"><?php esc_html_e( 'Latest syncs', 'flo-sync' ); ?></h2>

		<table class="nmf-sync-table">
			<thead>
				<tr>
					<th><?php esc_html_e( 'Type', 'flo-sync' ); ?></th>
					<th><?php esc_html_e( 'Latest sync', 'flo-sync' ); ?></th>
					<th><?php esc_html_e( 'Latest Ajax sync', 'flo-sync' ); ?></th>
					<th><?php esc_html_e( 'Latest Cron sync', 'flo-sync' ); ?></th>
				</tr>
			</thead>
			<tbody>
				<?php
				$syncs = Sync_Updated_Status::get_all();
				foreach ( $syncs as $sync_type => $data ) {
					echo '<tr>';
					echo '<td>' . esc_html( Sync_Updated_Status::get_display_name( $sync_type ) ) . '</td>';
					echo '<td class="nmf-latest-sync" data-option="' . esc_attr( $data['option_name'] ) . '">' . esc_html( $data['times']['main'] ) . '</td>';
					echo '<td>' . esc_html( $data['times']['ajax'] ) . '</td>';
					echo '<td>' . esc_html( $data['times']['cron'] ) . '</td>';
					echo '</tr>';
				}
				?>
			</tbody>
		</table>
		<h2 id="cron-events"><?php esc_html_e( 'Cron events', 'flo-sync' ); ?></h2>
		<table class="nmf-sync-table">
			<thead>
			<tr>
				<th><?php esc_html_e( 'Event', 'flo-sync' ); ?></th>
				<th><?php esc_html_e( 'Is enabled', 'flo-sync' ); ?></th>
				<th><?php esc_html_e( 'Status', 'flo-sync' ); ?></th>
				<th><?php esc_html_e( 'Recurrence', 'flo-sync' ); ?></th>
				<th><?php esc_html_e( 'Next scheduled', 'flo-sync' ); ?></th>
			</tr>
			</thead>
			<tbody>
			<?php
			$cron_events = Cron::get_all_cron_events();

			foreach ( $cron_events as $cron_event ) {
				echo '<tr>';
				echo '<td>' . esc_html( $cron_event->get_event() ) . '</td>';
				echo '<td>' . esc_html( $cron_event->get_is_enabled() ) . '</td>';
				echo '<td>' . esc_html( $cron_event->get_status() ) . '</td>';
				echo '<td>' . esc_html( $cron_event->get_recurrence() ) . '</td>';
				echo '<td>' . ( $cron_event->get_next_scheduled() ? esc_html( gmdate( 'Y-m-d H:i:s', $cron_event->get_next_scheduled() ) ) : '' ) . '</td>';
				echo '</tr>';
			}
			?>
			</tbody>
		</table>
		<h2 id="active-crons"><?php esc_html_e( 'Active cron locks', 'flo-sync' ); ?></h2>
		<table class="nmf-sync-table">
			<thead>
			<tr>
				<th><?php esc_html_e( 'Name', 'flo-sync' ); ?></th>
				<th><?php esc_html_e( 'Lock time', 'flo-sync' ); ?></th>
				<th><?php esc_html_e( 'Lock age', 'flo-sync' ); ?></th>
				<th><?php esc_html_e( 'Lock value', 'flo-sync' ); ?></th>
				<th><?php esc_html_e( 'Remove lock', 'flo-sync' ); ?></th>
			</tr>
			</thead>
			<tbody>
			<?php
			$locks = Locks::get_all();

			foreach ( $locks as $lock_name => $lock ) {
				echo '<tr>';
				echo '<td>' . esc_html( $lock_name ) . '</td>';
				echo '<td>' . esc_html( gmdate( 'Y-m-d H:i:s', $lock['time'] ) ) . '</td>';
				echo '<td>' . esc_html( Helpers::get_timestamp_age( $lock['time'] ) ) . '</td>';
				echo '<td>' . esc_html( $lock['value'] ) . '</td>';
				echo '<td><a href="#" class="nmf-cron-remove" data-lock-name="' . esc_attr( $lock_name ) . '">' . esc_html__( 'Remove', 'flo-sync' ) . '</a></td>';
				echo '</tr>';
			}
			?>
			</tbody>
		</table>
		<h2 id="hub-accounts"><?php esc_html_e( 'Hub Accounts', 'flo-sync' ); ?></h2>
		<h4 id="mas-sync-status"><?php esc_html_e( 'Multi-account sync status', 'flo-sync' ); ?></h4>
		<?php
		Backoffice_Accounts::is_multiple_stocks_enabled()
			? esc_html_e( 'Enabled', 'flo-sync' )
			: esc_html_e( 'Disabled', 'flo-sync' );
		?>
		<h4 id="hub-account-list"><?php esc_html_e( 'Accounts', 'flo-sync' ); ?></h4>
		<?php
		$all_hub_accounts = Backoffice_Accounts::get_all();
		echo '<pre>';
		print_r( $all_hub_accounts );
		echo '</pre>';
		?>
		<h4 id="invalid-hub-accounts"><?php esc_html_e( 'Invalid Hub Accounts', 'flo-sync' ); ?></h4>
		<?php
		echo '<pre>';
		print_r( Backoffice_Accounts::get_invalid_accounts() );
		echo '</pre>';
		?>
		<h2 id="income-account-codes"><?php esc_html_e( 'Income Account Codes', 'flo-sync' ); ?></h2>
		<?php
		$payment_gateways = WC()->payment_gateways->payment_gateways();
		?>
		<table class="nmf-sync-table">
			<thead>
				<tr>
					<th><?php esc_html_e( 'Hub account', 'flo-sync' ); ?></th>
					<?php
					foreach ( $payment_gateways as $payment_gateway ) {
						echo '<th>' . esc_html( $payment_gateway->id ) . '</th>';
					}
					?>
				</tr>
			</thead>
			<tbody>
			<?php

			foreach ( $all_hub_accounts as $hub_account ) {
				$income_account_codes = $hub_account->get_income_account_codes();
				echo '<tr>';
				echo '<td>' . esc_html( $hub_account->user ) . '</td>';
				foreach ( $payment_gateways as $payment_gateway ) {
					echo '<td>' . ( isset( $income_account_codes[$payment_gateway->id] ) ? esc_html( $income_account_codes[$payment_gateway->id]->get_account_code() ) : '' ) . '</td>';
				}
				echo '</tr>';
			}
			?>
			</tbody>
		</table>
		<h2 id="vat-account-codes"><?php esc_html_e( 'VAT Account Codes', 'flo-sync' ); ?></h2>
		<table class="nmf-sync-table">
			<thead>
			<tr>
				<th><?php esc_html_e( 'Hub account', 'flo-sync' ); ?></th>
				<th>0%</th>
				<th>6%</th>
				<th>12%</th>
				<th>25%</th>
			</tr>
			</thead>
			<tbody>
			<?php

			foreach ( $all_hub_accounts as $hub_account ) {
				$vat_account_codes = $hub_account->get_vat_account_codes();
				echo '<tr>';
				echo '<td>' . esc_html( $hub_account->user ) . '</td>';
				echo '<td>' . esc_html( $vat_account_codes[0]?->get_account_code() ) . '</td>';
				echo '<td>' . esc_html( $vat_account_codes[6]?->get_account_code() ) . '</td>';
				echo '<td>' . esc_html( $vat_account_codes[12]?->get_account_code() ) . '</td>';
				echo '<td>' . esc_html( $vat_account_codes[25]?->get_account_code() ) . '</td>';
				echo '</tr>';
			}
			?>
			</tbody>
		</table>
		<h2 id="article-account-codes"><?php esc_html_e( 'Article Account Codes', 'flo-sync' ); ?></h2>
		<h4 id="table-wc_tax_rate_classes">Table wc_tax_rate_classes</h4>
		<table class="nmf-sync-table">
			<thead>
				<tr>
					<th>tax_rate_class_id</th>
					<th>name</th>
					<th>slug</th>
				</tr>
			</thead>
			<tbody>
			<?php
			$tax_rate_classes = DB_Helpers::get_all_rows_from_table( 'wc_tax_rate_classes' );

			foreach ( $tax_rate_classes as $tax_rate_class ) {
				echo '<tr>';
				echo '<td>' . esc_html( $tax_rate_class['tax_rate_class_id'] ) . '</td>';
				echo '<td>' . esc_html( $tax_rate_class['name'] ) . '</td>';
				echo '<td>' . esc_html( $tax_rate_class['slug'] ) . '</td>';
				echo '</tr>';
			}
			?>
			</tbody>
		</table>
		<h4 id="table-woocommerce_tax_rates">Table woocommerce_tax_rates</h4>
		<table class="nmf-sync-table">
			<thead>
			<tr>
				<th>tax_rate_id</th>
				<th>tax_rate_country</th>
				<th>tax_rate_state</th>
				<th>tax_rate</th>
				<th>tax_rate_name</th>
				<th>tax_rate_priority</th>
				<th>tax_rate_compound</th>
				<th>tax_rate_shipping</th>
				<th>tax_rate_order</th>
				<th>tax_rate_class</th>
			</tr>
			</thead>
			<tbody>
			<?php
			$tax_rates = DB_Helpers::get_all_rows_from_table( 'woocommerce_tax_rates' );

			foreach ( $tax_rates as $tax_rate ) {
				echo '<tr>';
				echo '<td>' . esc_html( $tax_rate['tax_rate_id'] ) . '</td>';
				echo '<td>' . esc_html( $tax_rate['tax_rate_country'] ) . '</td>';
				echo '<td>' . esc_html( $tax_rate['tax_rate_state'] ) . '</td>';
				echo '<td>' . esc_html( $tax_rate['tax_rate'] ) . '</td>';
				echo '<td>' . esc_html( $tax_rate['tax_rate_name'] ) . '</td>';
				echo '<td>' . esc_html( $tax_rate['tax_rate_priority'] ) . '</td>';
				echo '<td>' . esc_html( $tax_rate['tax_rate_compound'] ) . '</td>';
				echo '<td>' . esc_html( $tax_rate['tax_rate_shipping'] ) . '</td>';
				echo '<td>' . esc_html( $tax_rate['tax_rate_order'] ) . '</td>';
				echo '<td>' . esc_html( $tax_rate['tax_rate_class'] ) . '</td>';
				echo '</tr>';
			}
			?>
			</tbody>
		</table>
		<h4 id="option-mf_tax_rates_cls">Option mf_tax_rates_cls</h4>
		<?php
		echo '<pre>';
		print_r( get_option( 'mf_tax_rates_cls', __( 'Not set', 'flo-sync' ) ) );
		echo '</pre>';
		?>
		<h4 id="option-mf_tax_rates_ids">Option mf_tax_rates_ids</h4>
		<?php
		echo '<pre>';
		print_r( get_option( 'mf_tax_rates_ids', __( 'Not set', 'flo-sync' ) ) );
		echo '</pre>';
		?>
		<h4 id="option-mf_wc_tax_rules">Option mf_wc_tax_rules</h4>
		<table class="nmf-sync-table">
			<thead>
				<tr>
					<th>MF VAT ID (array key)</th>
					<th>VAT Slug (array item value 0)</th>
					<th>VAT Rate (array item value 1)</th>
				</tr>
			</thead>
			<tbody>
			<?php
			$tax_rules = get_option( 'mf_wc_tax_rules', array() );

			foreach ( $tax_rules as $tax_rule_id => $tax_rule ) {
				echo '<tr>';
				echo '<td>' . esc_html( $tax_rule_id ) . '</td>';
				echo '<td>' . esc_html( $tax_rule[0] ) . '</td>';
				echo '<td>' . esc_html( $tax_rule[1] ) . '</td>';
				echo '</tr>';
			}
			?>
			</tbody>
		</table>
		<h2 id="woocommerce-settings"><?php esc_html_e( 'WooCommerce settings', 'flo-sync' ); ?></h2>
		<h4 id="price-decimals"><?php esc_html_e( 'Price decimals', 'flo-sync' ); ?></h4>
		<p><?php echo esc_html( wc_get_price_decimals() ); ?></p>
		<h5>
			<?php
				printf(
						// translators: %s: hook name.
					esc_html__( 'Hooks for %s', 'flo-sync' ),
					'woocommerce_price_num_decimals'
				);
				?>
		</h5>
		<?php Debug::display_hooks( 'wc_get_price_decimals' ); ?>
		<h5>
			<?php
				printf(
						// translators: %s: WordPress option name.
					esc_html__( 'Hooks for the option retrieval of %s', 'flo-sync' ),
					'woocommerce_price_num_decimals'
				);
				?>
		</h5>
		<?php Debug::display_hooks( 'option_woocommerce_price_num_decimals' ); ?>
		<?php Debug::display_hooks( 'pre_option_woocommerce_price_num_decimals' ); ?>

		<h2 id="settings-pre-3"><?php esc_html_e( 'Settings Pre 3.0.0', 'flo-sync' ); ?></h2>
		<h4 id="settings-pre-3-main"><?php esc_html_e( 'Main settings', 'flo-sync' ); ?></h4>
		<?php
		echo '<pre>';
		print_r( get_option( 'nmf_settings_backup_pre.3.0.0', __( 'Not set', 'flo-sync' ) ) );
		echo '</pre>';
		?>
		<h4 id="settings-pre-3-aac"><?php esc_html_e( 'Article Account Codes', 'flo-sync' ); ?></h4>
		<?php
		echo '<pre>';
		print_r( get_option( 'nmf_article_account_codes_from_pre_3.0.0', __( 'Not set', 'flo-sync' ) ) );
		echo '</pre>';
		?>
	</div>
</div>
