<?php
/**
 * WP admin Sync view.
 *
 * @package flo-sync
 */

use NMFS\Settings;
use NMFS\Sync\Admin_Status;

defined( 'ABSPATH' ) || exit;
?>
<div class="wrap">
	<h2><?php esc_html_e( 'Northmill Sync', 'flo-sync' ); ?></h2>
	<div>
		<h3><?php esc_html_e( 'Automatic Sync Status', 'flo-sync' ); ?></h3>
		<?php Admin_Status::display_sync_status(); ?>
		<hr>

		<h3><?php esc_html_e( 'Reset automatic sync', 'flo-sync' ); ?></h3>
		<?php if ( Settings::is_setting_enabled( NMF_SYNC_STATUS ) ) : ?>
			<button name="mf_btn_reactivate_cron" id="mf_btn_reactivate_cron" class="button button-secondary">
				<?php echo esc_html__( 'Reset sync', 'flo-sync' ); ?>
			</button>
			<?php
		else :
			printf(
			// translators: %1$s: opening anchor tag, %2$s: closing anchor tag.
				esc_html__( 'Automatic sync is disabled. Re-enable it in %1$ssettings%2$s.', 'flo-sync' ),
				'<a href="' . esc_url( admin_url( 'admin.php?page=' . NMF_SYNC_SETTINGS_SLUG ) ) . '" target="_blank">',
				'</a>'
			);
		endif;
		?>
		<hr>

		<h3><?php esc_html_e( 'Manually sync all', 'flo-sync' ); ?></h3>

		<form method="POST" action="">

			<table id="nmf-sync-actions">
				<tbody>
					<tr>
						<td class="col-50">
							<?php $nonce = wp_create_nonce( 'mf_ajax_sync_nonce' ); ?>
							<input type="button"
								name="mf_btn_sync"
								id="mf_sync_now"
								data-nonce="<?php echo esc_attr( $nonce ); ?>"
								class="button button-primary"
								value="<?php esc_attr_e( 'Manual sync', 'flo-sync' ); ?>">
							<input type="button"
								name="mf_btn_resume_sync"
								id="mf_sync_resume"
								data-nonce="<?php echo esc_attr( $nonce ); ?>"
								class="button button-primary"
								style="display: none;"
								value="<?php esc_attr_e( 'Attempt Resume Sync', 'flo-sync' ); ?>">
							<p>
								<label for="mf_sync_per_page"><?php esc_html_e( 'Items per page', 'flo-sync' ); ?></label>
								<select name="mf_sync_per_page" id="mf_sync_per_page">
									<option value="10">10</option>
									<option value="20" selected>20</option>
									<option value="30">30</option>
									<option value="50">50</option>
									<option value="100">100</option>
									<option value="200">200</option>
								</select>
							</p>
							<p>
								<input type="checkbox" value="1" id="nmf_get_all_data" name="nmf_get_all_data" />
								<label for="nmf_get_all_data"><?php esc_html_e( 'Retrieve all data from Hub, not just recent changes.', 'flo-sync' ); ?></label><br>

								<input type="checkbox" value="1" id="mf_sync_auto_resume" name="mf_sync_auto_resume" />
								<label for="mf_sync_auto_resume"><?php esc_html_e( 'Auto-attempt resume on error', 'flo-sync' ); ?></label>
							</p>
							<p>
							</p>
						</td>
						<td class="col-25">
							<p style="margin-top: 0;">
								<strong><?php esc_html_e( 'Actions for manual sync', 'flo-sync' ); ?></strong><br>
								<?php esc_html_e( 'Leave all enabled for default sync.', 'flo-sync' ); ?><br>
							</p>

							<input type="checkbox" class="nmf-ajax-sync-filter" id="enabled_nmf_sync_groups" checked>
							<label for="enabled_nmf_sync_groups"><?php esc_html_e( 'Sync Article Groups', 'flo-sync' ); ?></label><br>

							<input type="checkbox" class="nmf-ajax-sync-filter" id="enabled_nmf_clean_groups" checked>
							<label for="enabled_nmf_clean_groups"><?php esc_html_e( 'Clean Article Groups', 'flo-sync' ); ?></label><br>

							<input type="checkbox" class="nmf-ajax-sync-filter" id="enabled_nmf_sync_campaigns" checked>
							<label for="enabled_nmf_sync_campaigns"><?php esc_html_e( 'Sync Campaigns', 'flo-sync' ); ?></label><br>

							<input type="checkbox" class="nmf-ajax-sync-filter" id="enabled_nmf_clean_campaigns" checked>
							<label for="enabled_nmf_clean_campaigns"><?php esc_html_e( 'Clean Campaigns', 'flo-sync' ); ?></label><br>

							<input type="checkbox" class="nmf-ajax-sync-filter" id="enabled_nmf_sync_campaign_article_sets" checked>
							<label for="enabled_nmf_sync_campaign_article_sets"><?php esc_html_e( 'Sync Article Sets', 'flo-sync' ); ?></label><br>
						</td>
						<td class="col-25">
							<input type="checkbox" class="nmf-ajax-sync-filter" id="enabled_nmf_sync_article_account_codes" checked>
							<label for="enabled_nmf_sync_article_account_codes"><?php esc_html_e( 'Sync Article Account Codes', 'flo-sync' ); ?></label><br>

							<input type="checkbox" class="nmf-ajax-sync-filter" id="enabled_nmf_sync_vat_accounts" checked>
							<label for="enabled_nmf_sync_vat_accounts"><?php esc_html_e( 'Sync VAT Account Codes', 'flo-sync' ); ?></label><br>

							<input type="checkbox" class="nmf-ajax-sync-filter" id="enabled_nmf_sync_store_settings" checked>
							<label for="enabled_nmf_sync_store_settings"><?php esc_html_e( 'Sync Store Settings', 'flo-sync' ); ?></label><br>

							<input type="checkbox" class="nmf-ajax-sync-filter" id="enabled_nmf_sync_other_account_codes" checked>
							<label for="enabled_nmf_sync_other_account_codes"><?php esc_html_e( 'Sync Other Account Codes', 'flo-sync' ); ?></label><br>

							<input type="checkbox" class="nmf-ajax-sync-filter" id="enabled_nmf_sync_income_account_codes" checked>
							<label for="enabled_nmf_sync_income_account_codes"><?php esc_html_e( 'Sync Income Account Codes', 'flo-sync' ); ?></label><br>

							<input type="checkbox" class="nmf-ajax-sync-filter" id="enabled_nmf_sync_articles" checked>
							<label for="enabled_nmf_sync_articles"><?php esc_html_e( 'Sync Articles', 'flo-sync' ); ?></label><br>

							<input type="checkbox" class="nmf-ajax-sync-filter" id="enabled_nmf_sync_article_stock" checked>
							<label for="enabled_nmf_sync_article_stock"><?php esc_html_e( 'Sync Article Stock', 'flo-sync' ); ?></label><br>

							<input type="checkbox" class="nmf-ajax-sync-filter" id="enabled_nmf_sync_orders" checked>
							<label for="enabled_nmf_sync_orders"><?php esc_html_e( 'Sync Orders', 'flo-sync' ); ?></label>
						</td>
					</tr>
				<tr>
					<td>
					</td>
					<td>&nbsp;</td>
				</tr>
				</tbody>
			</table>

		</form>

		<!--suppress HtmlFormInputWithoutLabel -->
		<textarea id="mf_sync_status" style="width: 100%;height: 500px;display: none;" disabled></textarea>
	</div>
</div>
